<?php
use Illuminate\Support\Facades\DB;
use App\Order;
use App\Notification;
use App\NotificationEvent;
use App\Notifications\PushNotification;
use App\Socialmedia;
use Illuminate\Support\Facades\Auth;
use App\PaypalTransaction;
use PayPal\Api\Amount;
use PayPal\Api\RefundRequest;
use PayPal\Api\Sale;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Rest\ApiContext;
use PayPal\Api\Payout;
use PayPal\Api\PayoutSenderBatchHeader;
use PayPal\Api\PayoutItem;
use PayPal\Api\Currency;
function release_funds_to_seller($order_id, $influencer_id, $seller_id, $order_amount){
  $check = PaypalTransaction::where('order_id' , $order_id)->where('type' , 'release')->first();
  if(!$check){
    $influencer = SocialMedia::find($influencer_id);
    if($influencer){
      $total = $influencer->earning + $order_amount;
      $influencer->earning = $total;
      $influencer->save();
      //GENERATE A TABLE AND MOVE DATA THERE FOR TRANSFER CRONE
    }
    pay_to_seller($order_id, $seller_id, $order_amount);
  }
}

function refund_to_buyer($order_id){
  $check = PaypalTransaction::where('order_id' , $order_id)->where('type' , 'refund')->first();
  if(!$check){
    pay_to_buyer($order_id);
  }
}

function pay_to_seller($order_id , $seller_id, $order_amount){
    $errorCodes = [
        '400' => '400: INVALID_REQUEST. Request is not well-formed, syntactically incorrect, or violates schema.',
        '401' => '401: AUTHENTICATION_FAILURE. Authentication failed due to invalid authentication credentials.',
        '403' => '403: NOT_AUTHORIZED. Authorization failed due to insufficient permissions.',
        '404' => '404: RESOURCE_NOT_FOUND. The specified resource does not exist.',
        '405' => '405: METHOD_NOT_SUPPORTED. The server does not implement the requested HTTP method.',
        '406' => '406: MEDIA_TYPE_NOT_ACCEPTABLE. The server does not implement the media type that would be acceptable to the client.',
        '415' => '415: UNSUPPORTED_MEDIA_TYPE. The server does not support the request payload’s media type.',
        '422' => '422: UNPROCESSABLE_ENTITY. The API cannot complete the requested action, or the request action is semantically incorrect or fails business validation.',
        '429' => '429: RATE_LIMIT_REACHED. Too many requests. Blocked due to rate limiting.',
        '500' => '500: INTERNAL_SERVER_ERROR. An internal server error has occurred.',
        '503' => '503: SERVICE_UNAVAILABLE. Service Unavailable.',
    ];
  $amount = (string) round($order_amount, 2);
  $seller = \App\PaymentAccount::where('user_id' , $seller_id)->where('type' , 'paypal')->first();
  $payouts = new Payout();
  $senderBatchHeader = new PayoutSenderBatchHeader();
  // #### Batch Header Instance
  $senderBatchHeader->setSenderBatchId(uniqid())
      ->setEmailSubject('You have recieved $'.$amount.' against order # '.$order_id.'!');

  // #### Sender Item
  // Please note that if you are using single payout with sync mode, you can only pass one Item in the request
  $currency = new Currency();
    $currency->setValue($amount)
              ->setCurrency('USD');
    $senderItem = new PayoutItem();
    $senderItem->setRecipientType('Email')
        ->setNote('You have recieved $'.$amount.' against order # '.$order_id.'!')
        ->setReceiver($seller->account_email)
        ->setSenderItemId("Order # ".$order_id)
        ->setAmount($currency);

    $payouts->setSenderBatchHeader($senderBatchHeader)
        ->addItem($senderItem);

    $paypal_conf = \Config::get('paypal');
    $api_context = new ApiContext(new OAuthTokenCredential(
            $paypal_conf['client_id'],
            $paypal_conf['secret'])
    );
    $api_context->setConfig($paypal_conf['settings']);
  /*// For Sample Purposes Only.
    $request = clone $payouts;*/

  // ### Create Payout
    try {
      $output = $payouts->create(['sync_mode' => true],$api_context);
      $payoutBatchId = $output->getBatchHeader()->getPayoutBatchId();

      try {
        /* get last payout status using payoutBatchId */
        $payoutBatch = \PayPal\Api\Payout::get($payoutBatchId, $api_context);
        $payoutItems = $payoutBatch->getItems();
        /* get payout item id */
        $payoutItemId = $payoutItems[0]->getPayoutItemId();
        // ### Get Payout Item Status
        try {
          /* get payout item status of last payout */
          ## below if i put a sleep function of 30 seconds it will return me transaction id if i remove sleep function it will not give transaction id##
          sleep(5);
          $output2 = \PayPal\Api\PayoutItem::get($payoutItemId, $api_context);
          if($output2->getTransactionStatus() == 'SUCCESS'){
            $pay = new PaypalTransaction();
            $pay->order_id = $order_id;
            $pay->user_id = $seller_id;
            $pay->payment_id = $output2->getTransactionId();
            $pay->amount = $amount;
            $pay->type = 'release';
            $pay->response = json_encode($output2);
            $pay->save();

              $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'release']])->first();
              if($failedTransfer) {
                  $failedTransfer->status = 'successful';
                  $failedTransfer->response_msg = '200: The request succeeded.';
                  $failedTransfer->response_json = '';
                  $failedTransfer->save();
              }

          }
        } catch (PayPal\Exception\PayPalConnectionException $ex) {
          $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'release']])->first();
          if(!$failedTransfer) {
              $failedTransfer = new \App\FailedTransfer();
              $failedTransfer->status = 'pending';
          }
          $failedTransfer->order_id = $order_id;
          $failedTransfer->amount = $order_amount;
          $failedTransfer->payment_type = 'paypal';
          $failedTransfer->transaction_type = 'release';
          $failedTransfer->response_msg = isset($errorCodes[$ex->getCode()]) ? $errorCodes[$ex->getCode()] : $ex->getCode().': '. $ex->getMessage();
          $failedTransfer->response_json = $ex->getData();

          $failedTransfer->save();
        }
      } catch (PayPal\Exception\PayPalConnectionException $ex) {
          $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'release']])->first();
          if(!$failedTransfer) {
              $failedTransfer = new \App\FailedTransfer();
              $failedTransfer->status = 'pending';
          }
          $failedTransfer->order_id = $order_id;
          $failedTransfer->amount = $order_amount;
          $failedTransfer->payment_type = 'paypal';
          $failedTransfer->transaction_type = 'release';
          $failedTransfer->response_msg = isset($errorCodes[$ex->getCode()]) ? $errorCodes[$ex->getCode()] : $ex->getCode().': '. $ex->getMessage();
          $failedTransfer->response_json = $ex->getData();

          $failedTransfer->save();
      }
    } catch (PayPal\Exception\PayPalConnectionException $ex) {
        $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'release']])->first();
        if(!$failedTransfer) {
            $failedTransfer = new \App\FailedTransfer();
            $failedTransfer->status = 'pending';
        }
          $failedTransfer->order_id = $order_id;
          $failedTransfer->amount = $order_amount;
          $failedTransfer->payment_type = 'paypal';
          $failedTransfer->transaction_type = 'release';
          $failedTransfer->response_msg = isset($errorCodes[$ex->getCode()]) ? $errorCodes[$ex->getCode()] : $ex->getCode().': '. $ex->getMessage();
          $failedTransfer->response_json = $ex->getData();

          $failedTransfer->save();
      /*echo $ex->getCode();
      echo $ex->getData();
      die($ex);*/
    }
}

function pay_to_buyer($order_id, $seller_id = null, $buyer_id = null){
  /*Get order transaction details*/
    $errorCodes = [
        '400' => '400: INVALID_REQUEST. Request is not well-formed, syntactically incorrect, or violates schema.',
        '401' => '401: AUTHENTICATION_FAILURE. Authentication failed due to invalid authentication credentials.',
        '403' => '403: NOT_AUTHORIZED. Authorization failed due to insufficient permissions.',
        '404' => '404: RESOURCE_NOT_FOUND. The specified resource does not exist.',
        '405' => '405: METHOD_NOT_SUPPORTED. The server does not implement the requested HTTP method.',
        '406' => '406: MEDIA_TYPE_NOT_ACCEPTABLE. The server does not implement the media type that would be acceptable to the client.',
        '415' => '415: UNSUPPORTED_MEDIA_TYPE. The server does not support the request payload’s media type.',
        '422' => '422: UNPROCESSABLE_ENTITY. The API cannot complete the requested action, or the request action is semantically incorrect or fails business validation.',
        '429' => '429: RATE_LIMIT_REACHED. Too many requests. Blocked due to rate limiting.',
        '500' => '500: INTERNAL_SERVER_ERROR. An internal server error has occurred.',
        '503' => '503: SERVICE_UNAVAILABLE. Service Unavailable.',
    ];
  $transaction = PaypalTransaction::where('order_id' , $order_id)->first();
  if($transaction){

    $amount = round($transaction->amount, 2);
    //$tax = round(($amount)/10); // don't add refund in case of buyer
    $tax = 0;

    $amount = $amount+$tax;
    $amount = (string)$amount;

    $amt = new Amount();
    $amt->setTotal($amount)
        ->setCurrency('USD');
    $refund = new RefundRequest();
    $refund->setAmount($amt);

    $sale = new Sale();
    $sale->setId($transaction->payment_id);
    //dd($sale);

    $paypal_conf = \Config::get('paypal');
    $api_context = new ApiContext(new OAuthTokenCredential(
            $paypal_conf['client_id'],
            $paypal_conf['secret'])
    );
    $api_context->setConfig($paypal_conf['settings']);

    try {
      $refundedSale = $sale->refundSale($refund, $api_context);
      if($refundedSale->getState() == 'completed'){
        $pay = new PaypalTransaction();
        $pay->order_id = $order_id;
        $pay->user_id = $transaction->user_id;
        $pay->payment_id = $transaction->payment_id;
        $pay->amount = $transaction->amount;
        $pay->type = 'refund';
        $pay->response = json_encode($refundedSale);
        $pay->save();

        // failed transfers details
          $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'refund']])->first();
          if($failedTransfer) {
              $failedTransfer->status = 'successful';
              $failedTransfer->response_msg = '200: The request succeeded.';
              $failedTransfer->response_json = '';
              $failedTransfer->save();
          }
      }
    } catch (PayPal\Exception\PayPalConnectionException $ex) {
      $failedTransfer = \App\FailedTransfer::where([['order_id', $order_id], ['transaction_type', 'refund']])->first();
      if(!$failedTransfer) {
          $failedTransfer = new \App\FailedTransfer();
          $failedTransfer->status = 'pending';
      }
      $failedTransfer->order_id = $order_id;
      $failedTransfer->amount = $transaction->amount;
      $failedTransfer->payment_type = 'paypal';
      $failedTransfer->transaction_type = 'refund';
      $failedTransfer->response_msg = isset($errorCodes[$ex->getCode()]) ? $errorCodes[$ex->getCode()] : $ex->getCode().': '. $ex->getMessage();
      $failedTransfer->response_json = $ex->getData();

      $failedTransfer->save();
      /*echo $ex->getCode();
      echo $ex->getData();
      die($ex);*/
    } catch (Exception $ex) {
      /*die($ex);*/
    }
  }
}

function is_in_top10($id){
  $total = Socialmedia::where('status' , 'Verified')->count();
  $percent_10 = ($total > 0) ? (round($total/10) >= 1) ? round($total/10) : 1 : 1;
  $top_10 = Socialmedia::where('status' , 'Verified')->orderBy('earning', 'desc')->limit($percent_10)->pluck('id')->toArray();
  $is_in_top10 = false;
  if(in_array($id, $top_10)){
    $is_in_top10 = true;
  }
  return $is_in_top10;
}

function get_user_balance_hisory(){

  $user = Auth::user();

  $orders_data = Order::whereRaw('seller_id = '.$user->id.' || buyer_id = '.$user->id )->where('status' , 'completed')->select('id','amount' , 'created_at', 'buyer_id', 'seller_id')->get();
  $monthly_earning = $yearly_earning = $all_time = $total_sales = $total_purchases = 0;
  $month = \Carbon\Carbon::now()->subMonth();
  $year = \Carbon\Carbon::now()->subYear();

  $yearly_sales = $yearly_purchases =  array(
      1 => 0,
      2 => 0,
      3 => 0,
      4 => 0,
      5 => 0,
      6 => 0,
      7 => 0,
      8 => 0,
      9 => 0,
      10 => 0,
      11 => 0,
      12 => 0,
  );
  foreach ($orders_data as $order){
    if($order->seller_id == $user->id){
      $all_time = $all_time + $order->amount;
      if($order->created_at >= $month){
        $monthly_earning = $monthly_earning + $order->amount;
      }
      if($order->created_at >= $year){
        $yearly_earning = $yearly_earning + $order->amount;
      }
      $yearly_sales[$order->created_at->format('n')] = $yearly_sales[$order->created_at->format('n')] + $order->amount;
      $total_sales = $total_sales +1;
    }elseif ($order->buyer_id == $user->id){
      $total_purchases = $total_purchases +1;
      $yearly_purchases[$order->created_at->format('n')] = $yearly_purchases[$order->created_at->format('n')] + $order->amount;
    }
  }
  $data = [
      'monthly' => $monthly_earning,
      'yearly' => $yearly_earning,
      'all_time' => $all_time,
      'yearly_sales' => $yearly_sales,
      'yearly_purchases' => $yearly_purchases,
      'total_purchases' => $total_purchases,
      'total_sales' => $total_sales,
  ];
 return $data;
}

?>