<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyUserRequest;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateProfileRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Role;
use App\Socialmedia;
use App\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;

class AdminsController extends Controller
{
    public function index()
    {
        //abort_unless(\Gate::allows('user_access'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $userRole = Role::where('title', 'User')->first();

        $users = User::where('role_id', '!=', $userRole->id)->where('id', '!=', Auth::user()->id)->orderBy('created_at', 'desc')->get();

        return view('admin.admins.users', compact('users'));
    }

    public function create()
    {
        //abort_unless(\Gate::allows('user_create'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $roles = Role::all()->pluck('title', 'id');

        return view('admin.admins.create', compact('roles'));
    }

    public function store(StoreUserRequest $request)
    {
        //abort_unless(\Gate::allows('user_create'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = User::create($request->all());
        $user->email_verified_at = date('Y-m-d H:i:s');
        $user->save();
        //$user->roles()->sync($request->input('roles', []));

        return redirect()->route('admin.admins.index');
    }

    public function edit($userId)
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = User::find($userId);

        $roles = Role::all()->pluck('title', 'id');

        //$user->load('roles');

        return view('admin.admins.edit', compact('roles', 'user'));
    }

    public function update(UpdateUserRequest $request, $userId)
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = User::find($userId);

        $user->update($request->all());

        return redirect()->route('admin.admins.index');
    }

    public function show($userId)
    {
        abort_unless(\Gate::allows('user_show'), 403);
        $user = User::find($userId);

        $user->load('roles');

        return view('admin.admins.show', compact('user'));
    }

    public function destroy($userId)
    {
        abort_unless(\Gate::allows('user_delete'), 403);
        $user = User::find($userId);

        $user->delete();

        return back();
    }

    public function massDestroy(MassDestroyUserRequest $request)
    {
        User::whereIn('id', request('ids'))->delete();

        return response(null, 204);
    }

    public function editProfile()
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = User::find(Auth::user()->id);

        $roles = Role::all()->pluck('title', 'id');

        //$user->load('roles');

        return view('admin.admins.edit_profile', compact('roles', 'user'));
    }

    public function updateProfile(UpdateProfileRequest $request)
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = User::find(Auth::user()->id);
        $user->name = $request->name;
        $user->phone = $request->phone;
        if(isset($request->password)) {
            $user->password = Hash::make($request->password);
        }
        $user->save();
        //$user->update($request->all());

        return redirect()->route('admin.admins.edit_profile')->with('success','Your Profile is Updated Successfully.');
    }

    public function showResetFrom() {
        return view('admin.emails.email');
    }

    public function dashboard() {

        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }

        $user = Auth::user();
        $currentYear = date('Y');

        // all months earnings
        $allMonthsEarnings = [];
        $thisYearEarning = 0;
        $thisMonthEarning = 0;
        for ($i = 1; $i <= 12; $i++) {
            $eachMonthEarningQuery = 'select sum(amount) as total from paypal_transactions where type="deposit" and month(created_at) = ' . sprintf("%02d", $i) . ' and year(created_at) = ' . $currentYear;
            $eachMonthEarningResult = DB::select($eachMonthEarningQuery);
            $eachMonthEarning = $eachMonthEarningResult && isset($eachMonthEarningResult[0]->total) ? $eachMonthEarningResult[0]->total : 0;
            $allMonthsEarnings[$i] = $eachMonthEarning;
            $thisYearEarning += $allMonthsEarnings[$i];
            if(date('m') == sprintf("%02d", $i)) {
                $thisMonthEarning = $allMonthsEarnings[$i];
            }
        }

        // total earning
        $totalEarningQuery = 'select sum(amount) as total from paypal_transactions';
        $totalEarningResult = DB::select($totalEarningQuery);
        $totalEarning = $totalEarningResult && isset($totalEarningResult[0]->total) ? $totalEarningResult[0]->total : 0;

        //deposit
        $completedEarningQuery = 'select count(*) as total from paypal_transactions where type="deposit"';
        $completedEarningResult = DB::select($completedEarningQuery);
        $completedEarning = $completedEarningResult && isset($completedEarningResult[0]->total) ? $completedEarningResult[0]->total : 0;

        // refund
        $pendingEarningQuery = 'select count(*) as total from paypal_transactions where type="refund"';
        $pendingEarningResult = DB::select($pendingEarningQuery);
        $pendingEarning = $pendingEarningResult && isset($pendingEarningResult[0]->total) ? $pendingEarningResult[0]->total : 0;

        $tiktokAccountsCount = Socialmedia::where([['account_type', 'Tiktok']])->count();
        $instagramAccountsCount = Socialmedia::where([['account_type', 'Instagram']])->count();
        $featuredCount = Socialmedia::where([['is_featured', 1]])->count();

        // top ten influencers
        $topTenInfluencersQuery = 'select earning as transaction_amount, account_name, profile_picture, followers_count
        from socialmedias where isnull(deleted_at) and earning > 0 order by transaction_amount desc, followers_count desc limit 10';

        /*'select sum(orders.amount) as transaction_amount, socialmedias.id, socialmedias.account_name, socialmedias.profile_picture, socialmedias.followers_count
        from socialmedias left join orders on socialmedias.id = orders.influencer_id 
        where isnull(socialmedias.deleted_at) AND orders.amount IS NOT NULL AND orders.status="completed"
        GROUP BY socialmedias.id, socialmedias.account_name, socialmedias.profile_picture, socialmedias.followers_count 
        ORDER BY transaction_amount desc, socialmedias.followers_count desc 
        LIMIT 10';*/
        $topTenInfluencersResult = DB::select($topTenInfluencersQuery);

        // no of users
        $noOfUsersQuery = 'select count(*) as total from users where isnull(deleted_at)';
        $noOfUsersResult = DB::select($noOfUsersQuery);
        $noOfUsers = $noOfUsersResult && isset($noOfUsersResult[0]->total) ? $noOfUsersResult[0]->total : 0;

        $earningDetails = [
            'allMonthsEarnings' => $allMonthsEarnings,
            'totalEarning' => $totalEarning,
            'completedEarning' => $completedEarning,
            'pendingEarning' => $pendingEarning,
            'thisYearEarning' => $thisYearEarning,
            'thisMonthEarning' => $thisMonthEarning,

            'janEarning' => $allMonthsEarnings[1],
            'febEarning' => $allMonthsEarnings[2],
            'marEarning' => $allMonthsEarnings[3],
            'aprEarning' => $allMonthsEarnings[4],
            'mayEarning' => $allMonthsEarnings[5],

            'tiktokAccountsCount' => $tiktokAccountsCount,
            'instagramAccountsCount' => $instagramAccountsCount,
            'featuredCount' => $featuredCount,
            'topTenInfluencers' => $topTenInfluencersResult,
            'noOfUsers' => $noOfUsers

        ];

        //echo "<pre>"; print_r($earningDetails); exit;

        $data = [
            'earningDetails' => $earningDetails,
        ];

        return view('admin.dashboard', $data);

    }
}

