<?php


namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyCampaignRequest;
use App\Http\Requests\StoreCampaignRequest;
use App\Http\Requests\UpdateCampaignRequest;
use App\Campaign;
use App\Post;
use App\Role;

class CampaignsController extends Controller
{
    public function index()
    {

        $campaigns = Campaign::leftJoin('socialmedias' , 'socialmedias.id' , '=' , 'campaigns.social_media_id')
                      ->select(
                          'campaigns.id',
                          'campaigns.social_media_id',
                          'campaigns.title',
                          'campaigns.price',
                          'campaigns.admin_status',
                          'campaigns.status',
                          'campaigns.description',
                          'socialmedias.account_handle',
                          'socialmedias.followers_count'
                      )
                      ->orderBy('campaigns.created_at', 'desc')->get();

        return view('admin.campaigns.index', compact('campaigns'));
    }


    public function create()
    {

        $influencerRole = Role::where('title', 'User')->first();
        $influencers = $influencerRole->users;
        $data = ["influencers"=>$influencers];

        return view('admin.campaigns.create', $data);
    }

    public function store(StoreCampaignRequest $request)
    {

        $campaign = Campaign::create($request->all());

        return redirect()->route('admin.campaigns.index');
    }

    public function edit(Campaign $campaign)
    {

        $influencerRole = Role::where('title', 'User')->first();
        $influencers = $influencerRole->users;
        $posts = Post::all();
        $data = ['campaign'=>$campaign, "influencers"=>$influencers, 'posts'=>$posts];

        return view('admin.campaigns.edit', $data);
    }

    public function update(UpdateCampaignRequest $request, Campaign $campaign)
    {
        $campaign->update($request->all());

        return redirect()->route('admin.campaigns.index');
    }

    public function update_status($id, $flag)
    {
      if($flag == 1){
        Campaign::find($id)->update(['admin_status' => 'approved']);
      }else if($flag == 0){
        Campaign::find($id)->update(['admin_status' => 'disapproved']);
      }

        return redirect()->route('admin.campaigns.index');
    }

    public function show(Campaign $campaign)
    {

        return view('admin.campaigns.show', compact('campaign'));
    }

    public function destroy(Campaign $campaign)
    {
        try {
            $campaign->delete();
            return back();
        } catch (\Exception $ex) {
            return redirect()->route('admin.campaigns.index')->with('error', 'Cannot delete this campaign, this campaign is found in In-Progress Orders.');
        }
    }

    public function massDestroy(MassDestroyCampaignRequest $request)
    {
        try {
            Campaign::whereIn('id', request('ids'))->delete();
            return response(null, 204);
        } catch (\Exception $ex) {
            return 'query_error';
        }
    }

}
