<?php


namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;
use App\NotificationEvent;
use App\NotificationEventTag;
use Illuminate\Http\Request;

class NotificationEventsController extends Controller
{
    public static $invalidTags = [], $validTags = [];

    public function index()
    {
        $data = [
            'eventsDetail' => NotificationEvent::event_values_array()
        ];

        return view('admin.notifications.notification_events', $data);
    }

    public function update(Request $request) {

        $notificationEvents = NotificationEvent::events_array();
        self::$validTags = NotificationEventTag::tag_values_array();

        if($request->section_name == 'register_events') {
            $this->setEventValues('create_user_event', $request->create_user_event, $notificationEvents);
        }

        if($request->section_name == 'campaign_events') {
            $this->setEventValues('create_campaign_event', $request->create_campaign_event, $notificationEvents);
            $this->setEventValues('in_progress_campaign_event', $request->in_progress_campaign_event, $notificationEvents);
            $this->setEventValues('completed_campaign_event', $request->completed_campaign_event, $notificationEvents);
            $this->setEventValues('accepted_campaign_event', $request->accepted_campaign_event, $notificationEvents);
            $this->setEventValues('rejected_campaign_event', $request->rejected_campaign_event, $notificationEvents);
        }

        if($request->section_name == 'order_events') {
            $this->setEventValues('create_order_event', $request->create_order_event, $notificationEvents);
            $this->setEventValues('in_progress_order_event', $request->in_progress_order_event, $notificationEvents);
            $this->setEventValues('completed_order_event', $request->completed_order_event, $notificationEvents);
        }

        if($request->section_name == 'balance_events') {
            $this->setEventValues('add_balance_event', $request->add_balance_event, $notificationEvents);
            $this->setEventValues('withdraw_balance_event', $request->withdraw_balance_event, $notificationEvents);
        }

        if($request->section_name == 'ticket_events') {
            $this->setEventValues('normal_ticket_event', $request->normal_ticket_event, $notificationEvents);
            $this->setEventValues('suspend_user_event', $request->suspend_user_event, $notificationEvents);
            $this->setEventValues('resolve_ticket_event', $request->resolve_ticket_event, $notificationEvents);
        }

        if(sizeof(self::$invalidTags) > 0) {
            return redirect('/admin/notification_events')->with( 'error', 'Text cannot be updated with Invalid Tags: ' . implode(', ', self::$invalidTags ) );
        }

        return redirect('/admin/notification_events')->with('success', 'Updated Successfully.');
    }

    public function setEventValues($eventName, $eventText, $notificationEvents) {

        $tags = self::getInbetweenStrings( $eventText, '{', '}' );
        foreach ( $tags as $tag) {
            if( !in_array( $tag, self::$validTags ) ) {
                self::$invalidTags[] = $tag;
            }
        }
        if( sizeof( self::$invalidTags ) > 0 ) {
            return false;
        }

        $notificationEvent = in_array( $eventName, $notificationEvents ) ? NotificationEvent::where('name', $eventName)->first() : new NotificationEvent();
        $notificationEvent->name = $eventName;
        $notificationEvent->text = $eventText;
        $notificationEvent->tags = json_encode( $tags );
        $notificationEvent->save();
    }

    public static function getInbetweenStrings($str, $start, $end){
        $matches = array();
        $regex = "/$start([a-zA-Z0-9_]*)$end/";
        preg_match_all($regex, $str, $matches);
        return $matches[1];
    }

}
