<?php


namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;

use App\Http\Requests\MassDestroyNotificationRequest;
use App\Http\Requests\StoreNotificationRequest;
use App\Http\Requests\UpdateNotificationRequest;
use App\Notification;
use App\User;
use Illuminate\Support\Facades\Auth;


class NotificationsController extends Controller
{

    public function index()
    {
        if(!\Gate::allows('notification_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $authUser = Auth::user();

        $notifications = Notification::where( 'to_user_id', $authUser->id )->orderBy('created_at', 'desc')->get();

        return view('admin.notifications.index', compact('notifications', 'authUser'));
    }


    public function create()
    {
        if(!\Gate::allows('notification_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = Auth::user();
        $users = User::where('id', '!=', $user->id)->get();
        $data = [
            'loggedInUser' => $user,
            'users' => $users,
        ];
        return view('admin.notifications.create', $data);
    }

    public function store(StoreNotificationRequest $request)
    {
        if(!\Gate::allows('notification_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $notification = Notification::create($request->all());
        return redirect()->route('admin.notifications.index');
    }

    public function edit(Notification $notification)
    {
        if(!\Gate::allows('notification_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = Auth::user();
        if($notification->from_user_id != $user->id) {
            return redirect('/admin/notifications')->with('error','You can not edit this notification.');
        }

        $users = User::where('id', '!=', $user->id)->get();
        $data = [
            'loggedInUser' => $user,
            'users' => $users,
            'notification' => $notification
        ];
        return view('admin.notifications.edit', $data);
    }

    public function update(UpdateNotificationRequest $request, Notification $notification)
    {
        if(!\Gate::allows('notification_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = Auth::user();
        if($notification->from_user_id != $user->id) {
            return redirect('/admin/notifications')->with('error','You can not edit this notification.');
        }

        $notification->update($request->all());
        return redirect()->route('admin.notifications.index');
    }

    public function show(Notification $notification)
    {
        if(!\Gate::allows('notification_show')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        return view('admin.notifications.show', compact('notification'));
    }

    public function destroy(Notification $notification)
    {
        if(!\Gate::allows('notification_delete')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = Auth::user();
        //if($notification->from_user_id != $user->id) {
            //return redirect('/admin/notifications')->with('error','You can not delete this notification.');
        //}

        $notification->delete();

        return back();
    }

    public function massDestroy(MassDestroyNotificationRequest $request)
    {
        if(!\Gate::allows('notification_delete')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = Auth::user();
        $notifications = Notification::whereIn('id', request('ids'))->get();
        $notificationIds = [];
        foreach ($notifications as $notification) {
            if ($notification->from_user_id != $user->id) {
                $notificationIds[] = $notification->id;
                //return redirect('/admin')->with('error', 'You can not edit this notification.');
            }
        }
        if(count($notificationIds) > 0) {
            return redirect('/admin/notifications')->with('error', 'You can not delete notifications with ids: ' .  implode(', ', $notificationIds));
        }

        Notification::whereIn('id', request('ids'))->delete();

        return response(null, 204);
    }

}
