<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyPermissionRequest;
use App\Http\Requests\StorePermissionRequest;
use App\Http\Requests\UpdatePermissionRequest;
use App\Permission;
use App\Role;

class PermissionsController extends Controller
{
    public function index()
    {
        //abort_unless(\Gate::allows('permission_access'), 403);
        if(!\Gate::allows('permission_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $permissions = Permission::all();

        return view('admin.permissions.index', compact('permissions'));
    }

    public function create()
    {
        //abort_unless(\Gate::allows('permission_create'), 403);
        if(!\Gate::allows('permission_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        return view('admin.permissions.create');
    }

    public function store(StorePermissionRequest $request)
    {
        //abort_unless(\Gate::allows('permission_create'), 403);
        if(!\Gate::allows('permission_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $permission = Permission::create($request->all());
        $adminRoles = Role::where('title', 'Admin')->get();

        foreach ($adminRoles as $adminRole) {
            $adminRole->permissions()->attach($permission->id);
        }

        return redirect()->route('admin.permissions.index');
    }

    public function edit(Permission $permission)
    {
        //abort_unless(\Gate::allows('permission_edit'), 403);
        if(!\Gate::allows('permission_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        return view('admin.permissions.edit', compact('permission'));
    }

    public function update(UpdatePermissionRequest $request, Permission $permission)
    {
        //abort_unless(\Gate::allows('permission_edit'), 403);
        if(!\Gate::allows('permission_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $permission->update($request->all());

        return redirect()->route('admin.permissions.index');
    }

    public function show(Permission $permission)
    {
        //abort_unless(\Gate::allows('permission_show'), 403);
        if(!\Gate::allows('permission_show')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        return view('admin.permissions.show', compact('permission'));
    }

    public function destroy(Permission $permission)
    {
        //abort_unless(\Gate::allows('permission_delete'), 403);
        if(!\Gate::allows('permission_delete')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $permission->delete();

        return back();
    }

    public function massDestroy(MassDestroyPermissionRequest $request)
    {
        Permission::whereIn('id', request('ids'))->delete();

        return response(null, 204);
    }
}
