<?php


namespace App\Http\Controllers\Admin;
use App\Http\Controllers\Controller;

use App\Http\Requests\MassDestroyTicketRequest;
use App\Http\Requests\StoreTicketRequest;
use App\Http\Requests\UpdateTicketRequest;
use App\Notification;
use App\Order;
use App\Role;
use App\Ticket;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;


class TicketsController extends Controller
{
    public function index()
    {
        if(!\Gate::allows('ticket_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $authUser = Auth::user();
        if($authUser->role->title == 'Admin') {
            //$tickets = Ticket::where('status' , 'Initiated')->get();
            $tickets = Ticket::orderBy('created_at', 'desc')->get();
        } else {
            $tickets = Ticket::where('user_id', $authUser->id)->orWhere('against_user_id', $authUser->id)->orderBy('created_at', 'desc')->get();
        }

        return view('admin.tickets.index', compact('tickets', 'authUser'));
    }

    public function create()
    {
        if(!\Gate::allows('ticket_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = Auth::user();
        $users = Role::users_not_admin($user);
        $data = [
            'users' => $users,
            'user' => $user
        ];
        return view('admin.tickets.create', $data);
    }

    public function store(StoreTicketRequest $request)
    {
        if(!\Gate::allows('ticket_create')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $ticket = new Ticket();
        $ticket->user_id = Auth::user()->id;
        $ticket->subject = $request->subject;
        $ticket->against_user_id = $request->against_user_id;
        $ticket->type = $request->against_user_id == 0 ? 'Normal' : 'Conflict';
        $ticket->status = 'Initiated';
        $ticket->description = $request->description;
        $ticket->save();
        return redirect()->route('admin.tickets.index');
    }

    public function edit(Ticket $ticket)
    {
        if(!\Gate::allows('ticket_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $user = Auth::user();
        if($ticket->user_id != $user->id) {
            return redirect('/admin/tickets')->with('error','You do not have permissions to it.');
        }
        $users = Role::users_not_admin($user);
        $data = [
            'users' => $users,
            'user' => $user,
            'ticket' => $ticket
        ];
        return view('admin.tickets.edit', $data);
    }

    public function update(UpdateTicketRequest $request, Ticket $ticket)
    {
        $ticket->subject = $request->subject;
        $ticket->against_user_id = $request->against_user_id;
        $ticket->type = $request->against_user_id == 0 ? 'Normal' : 'Conflict';
        $ticket->status = $request->status;
        $ticket->description = $request->description;
        $ticket->save();
        return redirect()->route('admin.tickets.index');
    }

    public function show(Ticket $ticket)
    {
        if(!\Gate::allows('ticket_show')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        return view('admin.tickets.show', compact('ticket'));
    }

    public function destroy(Ticket $ticket)
    {
        if(!\Gate::allows('ticket_delete')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $ticket->delete();

        return back();
    }

    public function massDestroy(MassDestroyTicketRequest $request)
    {
        if(!\Gate::allows('ticket_delete')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        Ticket::whereIn('id', request('ids'))->delete();

        return response(null, 204);
    }

    public function takeAction($ticketId){
        if(!\Gate::allows('ticket_action')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $ticket = Ticket::find($ticketId);
        return view('admin.tickets.action', compact('ticket'));
    }

    public function postAction(Request $request) {
        if(!\Gate::allows('ticket_action')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }
        $send_to_seller = $send_to_buyer = false;
        $ticket = Ticket::find($request->ticket_id);

        $message = ($request->message_to_sender != '') ? $request->message_to_sender : 'Admin has taken action against your ticket';

        if(!is_null($ticket->order_id)){
          ($request->send_to_seller) ? $send_to_seller =true : $send_to_seller =false;
          ($request->send_to_buyer) ? $send_to_buyer =true : $send_to_buyer =false;
          $order = Order::find($ticket->order_id);

          if($request->take_action == 1){
            $order->update(['status' => 'completed']);
            release_funds_to_seller($order->id, $order->influencer_id, $order->seller_id, $order->amount);
            $ticket->status = 'Paid To Seller';
          }elseif($request->take_action == 2){
            $order->update(['status' => 'order-refund']);
            $ticket->status = 'Refunded To Buyer';

            refund_to_buyer($order->id);
          }


          if($send_to_buyer){
            try {
              pushNotification('ticket_response' , 'ticket_response', $ticket->order_id,$order->buyer_id,null,null,$message);
            } catch (Exception $exception) {}
          }if($send_to_seller){
            try {
              pushNotification('ticket_response' , 'ticket_response', $ticket->order_id,$order->seller_id,null,null,$message );
            } catch (Exception $exception) {}
          }
        }else{
          if($request->take_action == 1){
            $ticket->status = 'Ticket Resolved';
          }elseif($request->take_action == 0){
            $ticket->status = 'No Action Taken';
          }

          try {
            pushNotification('ticket_response' , 'ticket_response', null,$ticket->user_id,null,null,$message );
          } catch (Exception $exception) {}

          if(!is_null($ticket->against_user_id)){
            try {
              pushNotification('ticket_response' , 'ticket_response', null,$ticket->against_user_id,null,null,$message );
            } catch (Exception $exception) {}
          }
        }

        $ticket->save();
        /*$fromUserId = Auth::user()->id;

        if($request->message_to_sender != '') {
            $toUserId = $ticket->user_id;
            $message = $request->message_to_sender;
            $this-> createNotification($message, $fromUserId, $toUserId);
        }

        if($request->take_action == '1') {
            $ticket->status = 'Resolved';
            $ticket->save();
        }

        if($request->take_action == '2') {
            $againstUser = User::find($ticket->against_user_id);
            $againstUser->status = 'Suspended';
            $againstUser->save();
        }*/
        return redirect()->route('admin.tickets.index');
    }

    public function createNotification($message, $from, $to = 0, $status = 'Unread') {
        $notification = new Notification();
        $notification->from_user_id = $from;
        $notification->to_user_id = $to;
        $notification->message = $message;
        $notification->status = $status;
        $notification->save();
    }

}
