<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyUserRequest;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Role;
use App\User;

class UsersController extends Controller
{
    public function index()
    {
        //abort_unless(\Gate::allows('user_access'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $adminRole = Role::where('title', 'Admin')->first();

        $users = User::where('role_id', '!=', $adminRole->id)->orderBy('created_at', 'desc')->get();

        return view('admin.users.users', compact('users'));
    }

    public function admins()
    {
        //abort_unless(\Gate::allows('user_access'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $adminRole = Role::where('title', 'Admin')->first();

        $users = User::where('role_id', $adminRole->id)->get();

        return view('admin.users.index', compact('users'));
    }

    public function create()
    {
        //abort_unless(\Gate::allows('user_create'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $roles = Role::all()->pluck('title', 'id');

        return view('admin.users.create', compact('roles'));
    }

    public function store(StoreUserRequest $request)
    {
        //abort_unless(\Gate::allows('user_create'), 403);
        if(!\Gate::allows('user_access')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user = User::create($request->all());
        $user->email_verified_at = date('Y-m-d H:i:s');
        $user->profile_link = url('profile/' . strtolower( str_replace(' ', '-', $user->name) ) . '-' . $user->id );
        $user->save();
        return $user;

        //return redirect()->route('admin.users.index');
    }

    public function edit(User $user)
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $roles = Role::all()->pluck('title', 'id');

        //$user->load('roles');

        return view('admin.users.edit', compact('roles', 'user'));
    }

    public function update(UpdateUserRequest $request, User $user)
    {
        //abort_unless(\Gate::allows('user_edit'), 403);
        if(!\Gate::allows('user_edit')) {
            return redirect('/admin')->with('error','You do not have permissions to it.');
        }

        $user->update($request->all());
        return $user;
        //$user->roles()->sync($request->input('roles', []));

        //return redirect()->route('admin.users.index');
    }

    public function show(User $user)
    {
        abort_unless(\Gate::allows('user_show'), 403);

        $user->load('roles');

        return view('admin.users.show', compact('user'));
    }

    public function destroy(User $user)
    {
        abort_unless(\Gate::allows('user_delete'), 403);

        try {

            $user->delete();
        } catch (\Exception $ex) {
            return back()->with('error', 'Cannot delete this user because orders are in progress.' );
        }

        return back();
    }

    public function massDestroy(MassDestroyUserRequest $request)
    {
        try {
            User::whereIn('id', request('ids'))->delete();
        } catch (\Exception $ex) {
            return 'error';
        }

        return response(null, 204);
    }

    public function changeStatus($id) {
        $user = User::find($id);
        $user->status = $user->status == 'Active' ? 'Inactive' : 'Active';
        $user->save();
        return redirect()->route('admin.users.index');
    }
}
