<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Password;

class ForgotPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset emails and
    | includes a trait which assists in sending these notifications from
    | your application to your users. Feel free to explore this trait.
    |
    */

    use SendsPasswordResetEmails;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    public function validateEmail(Request $request) {

        $user = User::where('email', $request->email)->first();
        if($user) {
            if(isset($request->admin_forget_password) && $user->role->title != 'Admin') {
                return 'Only Admins Can Reset Password Here.';
            }
            if(!isset($request->admin_forget_password) && $user->role->title == 'Admin') {
                return 'Admins Cannot Reset Password Here.';
            }
            return 'Success';
        } else {
            return 'Email Not Found.';
        }
    }

    public function sendResetLinkEmail(Request $request)
    {
        $this->validateEmail($request);

        // We will send the password reset link to this user. Once we have attempted
        // to send the link, we will examine the response then see the message we
        // need to show to the user. Finally, we'll send out a proper response.
        $response = $this->broker()->sendResetLink(
            $this->credentials($request)
        );

        $response == Password::RESET_LINK_SENT
            ? $this->sendResetLinkResponse($request, $response)
            : $this->sendResetLinkFailedResponse($request, $response);
        if($response == 'passwords.sent') {
            return back()->with('success', 'Password reset email is successfully sent.');
        }
    }
}
