<?php

namespace App\Http\Controllers\Auth;

use App\Referral;
use App\Role;
use App\User;
use App\Http\Controllers\Controller;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Str;
use Mail;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/home';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
            'phone' => ['required', 'numeric', 'digits_between:10,11'],
            'referral_code' => ['exists:users', 'nullable'],

            'country' => ['nullable', 'string'],
            'city' => ['nullable', 'string'],
            'zip_code' => ['nullable', 'string']
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        $userName = explode('@', $data['email']);
        $influencerRole = Role::where('title', 'User')->pluck('id');
        $user = User::create([
            'name' => $data['name'],
            'role_id' => $influencerRole[0],
            'email' => $data['email'],
            'phone' => $data['phone'],
            'referral_code' => 'REF-CODE-' . $userName[0],
            'password' => Hash::make($data['password']),

            'country' => isset($data['country']) ? $data['country'] : null,
            'city' => isset($data['city']) ? $data['city'] : null,
            'zip_code' => isset($data['zip_code']) ? $data['zip_code'] : null
        ]);

        if($data['referral_code'] != '') {
            $referralObj = User::where('referral_code', $data['referral_code'])->pluck('id');
            if($referralObj) {
                $referral = new Referral();
                $referral->referral_id = $referralObj[0];
                $referral->referred_id = $user->id;
                $referral->save();
            }

        }
        $user->profile_link = url('profile/' . strtolower( str_replace(' ', '-', $user->name) ) . '-' . $user->id );
        $user->save();

        return $user;

    }

    public function register(Request $request)
    {
        $this->validator($request->all())->validate();

        event(new Registered($user = $this->create($request->all())));

        $data = array(
            'from_name' => env('MAIL_FROM_NAME'),
            'from_email' => env('MAIL_FROM_ADDRESS'),
            'to_email' => $user->email,
            'to_name' => $user->name,
            'user_id' => $user->id,
            'token' => Str::random(32)
        );

        Mail::send( 'auth.emails.verify', $data, function($message) use ( $data ) {
            $message->to( $data['to_email'], $data['to_name'] )->subject
            ('CloutSource Account Verification Email');
            $message->from( $data['from_email'], $data['from_name'] );
        });
        $user->verify_token = $data['token'];
        $user->save();

        return [
            'user' => $user
        ];
        //$this->guard()->login($user);

        /*return $this->registered($request, $user)
            ?: redirect($this->redirectPath());*/
    }

    public function verifyEmail(Request $request) {
        $user = User::where('email', $request->email)->first();
        if($request->token == $user->verify_token) {
            $user->email_verified_at = date('Y-m-d H:i:s');
            $user->save();
            return redirect('/?verifiedToken=true');
        } else {
            return redirect('/')->with('error', 'Verify Token is Mismatched.');
        }
    }
}
