<?php


namespace App\Http\Controllers\Frontend;
use App\Campaign;
use App\Http\Controllers\Controller;
use App\Notification;
use App\Notifications\OrderRejectedNotification;
use App\Notifications\SellerReminderNotification;
use App\Order;
use App\Post;
use App\Socialmedia;
use App\Ticket;
use Auth;
use App\User;
use App\PaymentAccount;
use Illuminate\Support\Facades\DB;

class OrdersController extends Controller
{
    public function createOrder($id){
      $user = Auth::user();
      $check_accounts = PaymentAccount::where('user_id' , $user->id)->first();
      if(!$check_accounts){
        return redirect()->route('frontend.user.addPayments')->with('redirect_url', route('frontend.user.checkout', ['id' => $id]));
      }
      $post = Post::find($id);

      if($post){
        $campaign = DB::table('campaigns')->find($post->campaign_id , ['price', 'social_media_id']);
        $owner = DB::table('socialmedias')->find($campaign->social_media_id , ['user_id']);
        //dd($campaign);
        $order = new Order();

        $order->influencer_id = $post->influencer_id;
        $order->seller_id = $owner->user_id;
        $order->buyer_id = $post->brand_id;
        $order->post_id = $post->id;
        $order->amount = $campaign->price;
        $order->status = 'new';
        $order->payment_type = 'paypal';

        if($order->save()){
          return redirect()->route('frontend.user.redirect_paypal' , ['id' => $order->id]);
        }
      }else{
        return redirect('/');
      }
    }
    public function orderDetails($id) {
        $order = Order::where('orders.id', $id)
                  ->leftJoin('posts' , 'orders.post_id' , '=' , 'posts.id')
                  ->leftJoin('campaigns' , 'posts.campaign_id' , '=' , 'campaigns.id')
                  ->leftJoin('socialmedias' , 'orders.influencer_id' , '=' , 'socialmedias.id')
                  ->select(
                      'orders.*',
                      'posts.description as post_description',
                      'posts.image as post_image',
                      'posts.video as post_video',
                      'posts.link as post_link',
                      'posts.start_date',
                      'campaigns.id as campaign_id',
                      'campaigns.title as campaign_title',
                      'campaigns.description as campaign_description',
                      'campaigns.example_links',
                      'campaigns.example_image',
                      'campaigns.user_provides_description',
                      'campaigns.user_provides_links',
                      'campaigns.user_provides_media',
                      'socialmedias.account_handle as account_handle',
                      'socialmedias.user_id as owner_id',
                      'socialmedias.profile_picture',
                      'socialmedias.followers_count',
                      'socialmedias.account_type'
                  )->first();

        if(!$order){
          return abort('404');
        }elseif($order->buyer_id == Auth::user()->id || $order->owner_id == Auth::user()->id || $order->seller_id == Auth::user()->id || Auth::user()->role->title == 'Admin'){
            $ticket = null;
            $ticket = Ticket::where('order_id' , $id)->first();
          $order->buyer_email = User::where('id' , $order->buyer_id)->pluck('email')->first();

          $user = null;

          $influencer = Socialmedia::find($order->influencer_id);
          if($influencer) {
              $user = User::find($influencer->user_id);
          }
          $data = [
              'order' => $order,
              'ticket' => $ticket,
              'user' => $user
          ];
          return view('frontend.order.order_details', $data);
        }else{
          return abort('404');
        }

    }

    public function listOrders(){
      $orders = Order::whereRaw('orders.payment_status = "paid" AND orders.status != "new"')
          /*->leftJoin('posts' , 'posts.id' , '=' , 'orders.post_id')*/
          ->leftJoin('socialmedias' , 'socialmedias.id' , '=' , 'orders.influencer_id')
          ->where('orders.buyer_id' , Auth::user()->id)
          ->select(
              'orders.*',
              'socialmedias.account_handle'
          )->orderBy('created_at', 'desc')->paginate(10);

      return view('frontend.order.order_listing', ['orders' => $orders]);
    }

    public function updateOrderStatus($id , $status){
      $order = Order::where('orders.id' , $id)
                ->leftJoin('socialmedias' , 'socialmedias.id' , '=' , 'orders.influencer_id')
                ->select('orders.influencer_id','socialmedias.user_id', 'orders.buyer_id', 'socialmedias.account_handle', 'orders.seller_id', 'orders.amount')->first();

      //NOTIFICATION HERE

      if($order->user_id == Auth::user()->id || $order->buyer_id == Auth::user()->id){
        if($status == 'completed'){
          if(Auth::user()->id != $order->buyer_id){
            return response()->json(['flag' => false] , 403);
          }
        }
        Order::find($id)->update(['status' => $status]);

        if($status == 'in-progress'){
          pushNotification('order' , 'order_accepted', $id, $order->influencer_id, Auth::user()->id, $order->buyer_id, $order->account_handle);
        }

        if($status == 'feedback-required'){
          pushNotification('order' , 'feedback_required', $id, $order->influencer_id, Auth::user()->id, $order->buyer_id, $order->account_handle);
        }

        if($status == 'completed'){
          release_funds_to_seller($id, $order->influencer_id, $order->seller_id, $order->amount);
          pushNotification('order' , 'order_completed', $id, $order->influencer_id, $order->buyer_id, $order->seller_id, $order->account_handle, Auth::user()->name);
        }

        if($status == 'rejected'){
          pushNotification('order' , 'order_rejected', $id, $order->influencer_id, Auth::user()->id, $order->buyer_id, $order->account_handle);
          refund_to_buyer($id);
        }

        return response()->json(['flag' => true] , 200);
      }
        return response()->json(['flag' => false] , 403);
    }

    // here is the scheduler code to auto reject after 48 hr and reminders after 24 and 47 hrs to seller
    public function orderNotificationScheduler() {

        $pendingOrders = Order::where('status', 'pending')->get();
        $currentDateTime = date('Y-m-d H:i:s');
        foreach($pendingOrders as $order) {
            $createdAt = $order->created_at;
            $timeAfter24Hours = date("Y-m-d H:i:s", strtotime('+10 minutes', strtotime($createdAt)));
            $timeAfter47Hours = date("Y-m-d H:i:s", strtotime('+20 minutes', strtotime($createdAt)));
            $timeAfter48Hours = date("Y-m-d H:i:s", strtotime('+30 minutes', strtotime($createdAt)));

            echo $timeAfter24Hours . "<br>" . $timeAfter47Hours . "<br>" . $timeAfter48Hours . "<br>" . $currentDateTime . "<br>";

            if($timeAfter24Hours <= $currentDateTime && $timeAfter47Hours > $currentDateTime && $order->reminder_24_sent == 0) {
                $seller = $order->seller;
                $orderDetails = [
                    'order_id' =>$order->id,
                    'hours_remaining' => 24
                ];
                $seller->notify(new SellerReminderNotification($orderDetails));
                $order->reminder_24_sent = 1;
                $order->save();

                // create notification
                $notification = new Notification();
                $notification->from_user_id = 1;
                $notification->to_user_id = $seller->id;
                $message = 'Your order will be expired after 24 hours. <a href="' . url('frontend/order_details/' . $order->id) . '">Go To Order</a>';
                $notification->message = $message;
                $notification->save();
            }

            if($timeAfter47Hours <= $currentDateTime && $timeAfter48Hours > $currentDateTime && $order->reminder_47_sent == 0) {
                $seller = $order->seller;
                $orderDetails = [
                    'order_id' =>$order->id,
                    'hours_remaining' => 1
                ];
                $seller->notify(new SellerReminderNotification($orderDetails));
                $order->reminder_47_sent = 1;
                $order->save();

                // create notification
                $notification = new Notification();
                $notification->from_user_id = 1;
                $notification->to_user_id = $seller->id;
                $message = 'Your order will be expired after 1 hour. <a href="' . url('frontend/order_details/' . $order->id) . '">Go To Order</a>';
                $notification->message = $message;
                $notification->save();
            }

            if($timeAfter48Hours <= $currentDateTime && $order->reminder_47_sent == 1) {
                $order->status = 'rejected';
                $order->save();
                refund_to_buyer($order->id);

                $seller = $order->seller;
                $buyer = $order->buyer;
                $orderDetails = [
                    'order_id' =>$order->id
                ];
                $seller->notify(new OrderRejectedNotification($orderDetails));
                $buyer->notify(new OrderRejectedNotification($orderDetails));

                // create notification
                $notification = new Notification();
                $notification->from_user_id = 1;
                $notification->to_user_id = $seller->id;
                $message = 'This order is auto rejected due to no action in 48 hours. <a href="' . url('frontend/order_details/' . $order->id) . '">Go To Order</a>';
                $notification->message = $message;
                $notification->save();

                sleep(1);
            }
        }
    }
}
