<?php


namespace App\Http\Controllers\Frontend;
use App\CartItem;
use App\Http\Controllers\Controller;
use App\Order;
use App\PaymentAccount;
use App\PaypalTransaction;
use App\Post;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Input;
use PayPal\Api\Amount;
use PayPal\Api\Details;
use PayPal\Api\Item;
/** All Paypal Details class **/
use PayPal\Api\ItemList;
use PayPal\Api\Payer;
use PayPal\Api\Payment;
use PayPal\Api\PaymentExecution;
use PayPal\Api\RedirectUrls;
use PayPal\Api\Transaction;
use PayPal\Auth\OAuthTokenCredential;
use PayPal\Rest\ApiContext;
use Redirect;
use Session;
use URL;

class PaymentController extends Controller
{
    private $_api_context;
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        /** PayPal api context **/
        $paypal_conf = \Config::get('paypal');
        $this->_api_context = new ApiContext(new OAuthTokenCredential(
                $paypal_conf['client_id'],
                $paypal_conf['secret'])
        );
        $this->_api_context->setConfig($paypal_conf['settings']);
    }
    public function index()
    {
        //return view('paywithpaypal');
    }
    public function payWithpaypal($id)
    {
        $order = Order::find($id);
        $payer = new Payer();
        $payer->setPaymentMethod('paypal');
        $item_1 = new Item();
        $item_2 = new Item();

        $tax = round(($order->amount)/10);

        $item_1->setName('Campaign') /** item name **/
            ->setCurrency('USD')
            ->setQuantity(1)
            ->setPrice($order->amount); /** unit price **/
        $item_2->setName('Extra Charges') /** item name **/
            ->setCurrency('USD')
            ->setQuantity(1)
            ->setPrice($tax); /** unit price **/
        $item_list = new ItemList();
        $item_list->setItems(array($item_1 , $item_2));
        $amount = new Amount();
        $amount->setCurrency('USD')
            ->setTotal($order->amount + $tax);
        $transaction = new Transaction();
        $transaction->setAmount($amount)
            ->setItemList($item_list)
            ->setDescription('Transaction for order # '. $order->id);
        $redirect_urls = new RedirectUrls();
        $redirect_urls->setReturnUrl(URL::to('frontend/status?order_id='.$order->id)) /** Specify return URL **/
        ->setCancelUrl(URL::to('frontend/status'));
        $payment = new Payment();
        $payment->setIntent('Sale')
            ->setPayer($payer)
            ->setRedirectUrls($redirect_urls)
            ->setTransactions(array($transaction));
        /** dd($payment->create($this->_api_context));exit; **/
        try {
            $payment->create($this->_api_context);
        } catch (\PayPal\Exception\PPConnectionException $ex) {
            if (\Config::get('app.debug')) {
                //\Session::put('error', 'Connection timeout');
                return Redirect::to('/frontend/campaign_cart')->with('error', 'Connection timeout');
            } else {
                return Redirect::to('/frontend/campaign_cart')->with('error', 'Some error occur, sorry for inconvenient');
            }
        }
        foreach ($payment->getLinks() as $link) {
            if ($link->getRel() == 'approval_url') {
                $redirect_url = $link->getHref();
                break;
            }
        }
        /** add payment ID to session **/
        Session::put('paypal_payment_id', $payment->getId());
        if (isset($redirect_url)) {
            /** redirect to paypal **/
            return Redirect::away($redirect_url);
        }

        return Redirect::to('/frontend/campaign_cart')->with('error', 'Unknown error occurred');
    }
    public function getPaymentStatus(Request $request)
    {
        /** Get the payment ID before session clear **/
        $payment_id = Session::get('paypal_payment_id');
        $order_id = $request->input('order_id');
        //$payment_id = 'PAYID-L5SKB5A37S482847X625620K';
        /** clear the session payment ID **/
        Session::forget('paypal_payment_id');
        if ( empty($request->PayerID) || empty($request->token) ) {
            return Redirect::to('/frontend/campaign_cart')->with('error', 'Payment failed');
        }
        $payment = Payment::get($payment_id, $this->_api_context);
        $execution = new PaymentExecution();
        $execution->setPayerId($request->PayerID);
        /**Execute the payment **/
        $result = $payment->execute($execution, $this->_api_context);

      $transactions = $payment->getTransactions();
      $relatedResources = $transactions[0]->getRelatedResources();
      $sale = $relatedResources[0]->getSale();
      $saleId = $sale->getId();

        if ($result->getState() == 'approved') {

            /* Save order in database */

            $user = Auth::user();
            $orderAmount = 0;
            $influencerId = 0;

            $order = Order::find($order_id);

            if($order){
              $order->status = 'pending';
              $order->payment_status = 'paid';

              if($order->save()){
                $post = Post::find($order->post_id);

                $post->order_id = $order_id;
                $post->status = 'processed';
                $post->save();
              }

              /*$transaction = DB::table('transactions')->insert([
                  'user_id' => Auth::user()->id,
                  'order_id' => $order_id,
                  'transaction_amount' => $order->amount,
                  'type' => 'deposit',
                  'status' => 'completed',
                  'created_at' => Carbon::now(),
                  'updated_at' => Carbon::now(),
              ]);*/

              $pay = new PaypalTransaction();
              $pay->order_id = $order_id;
              $pay->user_id = Auth::user()->id;
              $pay->payment_id = $saleId;
              $pay->amount = $order->amount;
              $pay->type = 'deposit';
              $pay->response = json_encode($result);
              $pay->save();

              pushNotification('order', 'order_arrived', $order_id);
            }
            return redirect()->route('frontend.user.order_details' , ['id' => $order_id])->with('success', 'Payment successfully made.');
        }

      return redirect()->route('frontend.user.campaign_cart_details')->with('error', 'Payment failed');
    }

    public function addPayments(){
      $redirec_url = Session::get('redirect_url');
      $user = Auth::user();
      $user_paypal = PaymentAccount::where('user_id', $user->id)->where('type', 'paypal')->first();
      $user_card = PaymentAccount::where('user_id', $user->id)->where('type', 'card')->first();


        return view('frontend.payments.payment_details', ['paypal' => $user_paypal, 'card' => $user_card, 'redirect_url' => $redirec_url]);
    }

    public function savePayments(Request $request, $type){
      $user = Auth::user();
      if($type == 'paypal'){
        $account = PaymentAccount::updateOrCreate(['user_id' => $user->id, 'type' => 'paypal'],['account_email' => $request->paypal_email, 'is_refundable' => 0]);
      }elseif($type == 'card'){
        $account = PaymentAccount::updateOrCreate(['user_id' => $user->id, 'type' => 'card'],['card_number' => $request->card_number, 'cvv_number' => $request->cvv_number, 'expiry_month' => $request->expiry_month, 'expiry_year' => $request->expiry_year, 'is_refundable' => 0]);
      }

      if(!is_null($request->redirect_url)){
        return Redirect::to($request->redirect_url)->with('success' , 'Payment details added successfully.');
      }else{
        return redirect()->back()->with('success' , 'Payment details added successfully.');
      }

    }

    public function updateRefundable($type, $action){
      $user = Auth::user();
      if($action == 'add'){
        $query = PaymentAccount::where('user_id' , $user->id)->where('type' , $type)->update(['is_refundable' => 1 ]);
        if($query){
          PaymentAccount::where('user_id' , $user->id)->where('type', '!=' ,$type)->update(['is_refundable' => 0]);
          return response()->json(['status' => 0, 'response' => 'Successfull']);
        }
        return response()->json(['status' => 1, 'response' => 'Account does not exists']);
      }elseif($action == 'remove'){
        $query = PaymentAccount::where('user_id' , $user->id)->where('type' , $type)->update(['is_refundable' => 0]);
        if($query){
          $query2=PaymentAccount::where('user_id' , $user->id)->where('type', '!=' ,$type)->update(['is_refundable' => 1]);
          if ($query2){
            return response()->json(['status' => 0, 'response' => 'Successfull']);
          }else{
            PaymentAccount::where('user_id' , $user->id)->where('type' , $type)->update(['is_refundable' => 1]);
            return response()->json(['status' => 1, 'response' => 'Other account is not setup']);
          }
        }
        return response()->json(['status' => 1, 'response' => 'Account does not exists']);
      }
    }
}
