<?php

namespace App\Http\Controllers\Frontend;

use App\Http\Controllers\Controller;
use App\Socialmedia;
use App\SocialmediaObject;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
class SocialAccountsController extends Controller
{
    public function index() {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }
        $user = Auth::user();
        $socialAccounts = Socialmedia::where('user_id', $user->id)->get();

        /*$instagramAccounts = Socialmedia::where('user_id', $user->id)->where('account_type', 'Instagram')->get();
        $twitterAccounts = Socialmedia::where('user_id', $user->id)->where('account_type', 'Twitter')->get();
        $tiktokAccounts = Socialmedia::where('user_id', $user->id)->where('account_type', 'Tiktok')->get();
        $socialMediaObjects = [];
        foreach($instagramAccounts as $instagramAccount) {
            $socialMediaObject = new SocialmediaObject();
            $instagram_feed =  $socialMediaObject->initializeSocialMediaObject('Instagram', $instagramAccount->account_handle);
          if(!is_null($instagram_feed)){
            $socialMediaObjects[] = $instagram_feed;
          }
        }

        foreach($twitterAccounts as $twitterAccount) {
            $socialMediaObject = new SocialmediaObject();
            $twitter_feed = $socialMediaObject->initializeSocialMediaObject('Twitter', $twitterAccount->account_handle);
          if(!is_null($twitter_feed)){
            $socialMediaObjects[] = $twitter_feed;
          }
        }

        foreach($tiktokAccounts as $tiktokAccount) {
            $socialMediaObject = new SocialmediaObject();
            $tiktok_feed = $socialMediaObject->initializeSocialMediaObject('Tiktok', $tiktokAccount->account_handle);
            if(!is_null($tiktok_feed)){
              $socialMediaObjects[] = $tiktok_feed;
            }
        }*/
//  dd($socialMediaObjects);
        return view('frontend.add_social_accounts', ['socialAccounts' => $socialAccounts]);
    }

    public function viewProfile($profileID) {
        $user = User::where('profile_link', url('profile/' . $profileID))->first();
        if(!$user) {
            return redirect('/')->with('error','Invalid profile link.');
        }
        $socialAccounts = Socialmedia::where('user_id', $user->id)->get();
        return view('frontend.view_social_accounts', ['socialAccounts' => $socialAccounts, 'user' => $user]);
    }

    public function editProfileLink(Request $request, $id) {

        $profileId = str_replace(' ', '', $request->profile_id);

        $oldUser = User::where([ ['profile_link', url('profile/' . $profileId)], ['id', '<>', $id] ])->first(['id']);
        $user = User::find($id);
        if($oldUser) {
            return redirect( $user->profile_link )->with('error','This user profile link already exists.');
        }
        $user->profile_link = url('profile/' . $profileId);
        $user->save();
        return redirect( url('profile/' . $profileId) )->with('success','Profile link updated successfully.');
    }

    public function updateNullLink($id) {
        $user = User::find($id);
        $user->profile_link = url('profile/' . strtolower( str_replace(' ', '-', $user->name) ) . '-' . $user->id );
        $user->save();
        return redirect( $user->profile_link );
    }

    public function addAccount($account){
      switch ($account){
        case 'instagram':{
          return $this->addInstagramAccount();
        }
        case 'tiktok':{
          return $this->addTiktokAccount();
        }
        case 'twitter':{
          return $this->addTwitterAccount();
        }
        default:{
          abort('404');
        }
      }
    }

    public function postAccount(Request $request, $account){
      switch ($account){
        case 'instagram':{
          return $this->postInstagramAccount($request);
        }
        case 'tiktok':{
          return $this->postTiktokAccount($request);
        }
       /* case 'twitter':{
          return $this->postTwitterAccount($request);
        }*/
        default:{
          abort('404');
        }
      }
    }

    public function verifyAccount($account , $id){
      switch ($account){
        case 'instagram':{
          return $this->verifyAddedInstagramAccount($id);
        }
        case 'tiktok':{
          return $this->verifyAddedTiktokAccount($id);
        }
        /*case 'twitter':{
          return $this->verifyAddedTwitterAccount($id);
        }*/
        default:{
          abort('404');
        }
      }
    }

    public function postVerifyAccount(Request $request, $account){
      switch ($account){
        case 'instagram':{
          return $this->verifyInstagramAccount($request);
        }
        case 'tiktok':{
          return $this->verifyTiktokAccount($request);
        }
       /* case 'twitter':{
          return $this->verifyTwitterAccount($request);
        }*/
        default:{
          abort('404');
        }
      }
    }


    public function addTiktokAccount() {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }

        return view('frontend.add_tiktok_account');
    }

    public function postTiktokAccount(Request $request) {
      if(!Auth::check()) {
        return redirect('/')->with('error','You are not logged in.');
      }
      $alreadyExists = Socialmedia::where('account_handle', $request->account_handle)->where('account_type', 'Tiktok')->first();
      if($alreadyExists) {
        if($alreadyExists->status != 'Verified'){
          $alreadyExists->delete();
        }else{
          return redirect('/frontend/social')->with('error','Account already exists.');
          //return 'exists';
        }
      }

      $socialMediaObject = new SocialmediaObject();
      $initialisedSocialMediaObject = $socialMediaObject->initializeSocialMediaObject('Tiktok', $request->account_handle);
      if($initialisedSocialMediaObject) {
        return redirect('/frontend/verify/tiktok/' . $initialisedSocialMediaObject->getSocialMedia()->id );
          /*$user = [
              'id' => $initialisedSocialMediaObject->getSocialMedia()->id,
              'name' => $initialisedSocialMediaObject->getSocialMedia()->account_name,
              'avatar' => $initialisedSocialMediaObject->getSocialMedia()->profile_picture,
              'redirect_to' => url('/frontend/verify/tiktok/' . $initialisedSocialMediaObject->getSocialMedia()->id)
          ];
          return [
              'user' => $user
          ];*/
      }
      return redirect('/frontend/social')->with('error','Invalid Account Handle.');
      //return 'invalid';
    }

    public function verifyTiktokAccount(Request $request) {
      if(!Auth::check()) {
        return redirect('/')->with('error','You are not logged in.');
      }

      $socialMediaObject = new SocialmediaObject();
      $feed = $socialMediaObject->getTiktokFeeds($request->account_handle);
      //dd($feed);

      if(!$feed || strpos($feed->user->signature , $request->verification_code) === false) {
        return redirect()->route('frontend.social.home')->with('error', 'Not Verified.');
      } else {
        $socialMedia = Socialmedia::find($request->social_account_id);
        $socialMedia->status = 'Verified';
        $socialMedia->save();
        return redirect()->route('frontend.social.home')->with('success', 'Verified.');

      }
    }

    public function addInstagramAccount() {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }

        return view('frontend.add_instagram_account');
    }

    public function postInstagramAccount(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }
        $alreadyExists = Socialmedia::where('account_handle', $request->account_handle)->where('account_type', 'Instagram')->first();
        if($alreadyExists) {
          if($alreadyExists->status != 'Verified'){
            $alreadyExists->delete();
          }else{
            return redirect('/frontend/social')->with('error','Account already exists.');
            //return 'exists';
          }
        }

        $socialMediaObject = new SocialmediaObject();
        $initialisedSocialMediaObject = $socialMediaObject->initializeSocialMediaObject('Instagram', $request->account_handle);
        if($initialisedSocialMediaObject) {
            return redirect('/frontend/verify/instagram/' . $initialisedSocialMediaObject->getSocialMedia()->id );
            /*$user = [
                'id' => $initialisedSocialMediaObject->getSocialMedia()->id,
                'name' => $initialisedSocialMediaObject->getSocialMedia()->account_name,
                'avatar' => $initialisedSocialMediaObject->getSocialMedia()->profile_picture,
                'redirect_to' => url('/frontend/verify/instagram/' . $initialisedSocialMediaObject->getSocialMedia()->id)
            ];
            return [
                'user' => $user
            ];*/
        }
        //return 'invalid'; // invalid account handle
        return redirect('/frontend/social')->with('error','Invalid Account Handle.');
    }
    public function verifyAddedTiktokAccount($id) {

      $socialMedia = Socialmedia::find($id);
      if($socialMedia) {

        if(!Auth::check()) {
          return redirect('/')->with('error', 'You are not logged in.');
        }

        $socialMediaObject = new SocialmediaObject();
        $socialMediaObject = $socialMediaObject->initializeSocialMediaObject('Tiktok' , $socialMedia->account_handle);
        $feed = $socialMediaObject->getFeeds();
        $verification_code = $socialMedia->verification_code;
        $data = [
            'verification_code' => $verification_code,
            'feed'    => $feed,
            'account_handle'  => $socialMedia->account_handle,
            'social_account_id' => $socialMedia->id,
            'socialMediaObject' => $socialMediaObject
        ];

        return view('frontend.verify_tiktok_account', $data);

      }

    }

    public function verifyInstagramAccount(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }

        $socialMediaObject = new SocialmediaObject();
        $feed = $socialMediaObject->getInstagramFeeds($request->account_handle);
       // dd($feed);

        if(!$feed || strpos($feed->getBiography() , $request->verification_code) === false) {
          return redirect()->route('frontend.social.home')->with('error', 'Not Verified.');
        } else {
          $socialMedia = Socialmedia::find($request->social_account_id);
          $socialMedia->status = 'Verified';
          $socialMedia->save();
          return redirect()->route('frontend.social.home')->with('success', 'Verified.');
        }
    }

    public function removeAccount($id) {
        $socialMedia = Socialmedia::find($id);
        if($socialMedia) {
            $socialMedia->delete();
        }
        return redirect()->back();
    }

    public function verifyAddedInstagramAccount($id) {

        $socialMedia = Socialmedia::find($id);
        if($socialMedia) {

            if(!Auth::check()) {
                return redirect('/')->with('error', 'You are not logged in.');
            }

            $socialMediaObject = new SocialmediaObject();


            $socialMediaObject = $socialMediaObject->initializeSocialMediaObject('Instagram' , $socialMedia->account_handle);
            $feed = $socialMediaObject->getFeeds();
            $verification_code = $socialMedia->verification_code;

            $data = [
                'verification_code' => $verification_code,
                'feed'    => $feed,
                'account_handle'  => $socialMedia->account_handle,
                'social_account_id' => $socialMedia->id,
                'socialMediaObject' => $socialMediaObject
            ];

            return view('frontend.verify_instagram_account', $data);

        }

    }

    // twitter part

    public function addTwitterAccount() {

        return view('frontend.add_twitter_account');

    }

    public function postTwitterAccount(Request $request) {

        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }
        $alreadyExists = Socialmedia::where('account_handle', $request->account_handle)->where('account_type', 'Twitter')->first();
        if($alreadyExists) {
          if($alreadyExists->status != 'Verified'){
            $alreadyExists->delete();
          }else{
            return redirect('/frontend/social')->with('error','Account already exists.');
          }
        }
        $socialMediaObject = new SocialmediaObject();
        $initialisedSocialMediaObject = $socialMediaObject->initializeSocialMediaObject('Twitter', $request->account_handle);
        if($initialisedSocialMediaObject) {
            return redirect('/frontend/verify/twitter/' . $initialisedSocialMediaObject->getSocialMedia()->id );
        }
        return redirect('/frontend/social')->with('error','Invalid Account Handle or Zero Feeds in Account.');
    }

    public function verifyAddedTwitterAccount($id) {
        if(!Auth::check()) {
            return redirect('/')->with('error','You are not logged in.');
        }
        $socialMedia = Socialmedia::find($id);

        $socialMediaObject = new SocialmediaObject();
        $feed = $socialMediaObject->getTwitterFeeds($socialMedia->account_handle);
        $verification_code = $socialMedia->verification_code;
        $user = Auth::user();
        $data = [
            'verification_code' => $verification_code,
            'twitter_feed'    => $feed,
            'account_handle'  => $socialMedia->account_handle,
            'social_account_id' => $socialMedia->id
        ];

        return view('frontend.verify_twitter_account', $data);
    }

    public function verifyTwitterAccount(Request $request) {
        $socialMediaObject = new SocialmediaObject();
        $feed = $socialMediaObject->getTwitterFeeds($request->account_handle);

        if(count($feed) == 0) {
            return redirect()->route('frontend.social.home')->with('error', 'Cannot be verified, account has no feeds.');
        } else if($feed[0]['user']['description'] == $request->verification_code) {
            $socialMedia = Socialmedia::find($request->social_account_id);
            $socialMedia->status = 'Verified';
            $socialMedia->save();
            return redirect()->route('frontend.social.home')->with('success', 'Verified.');
        } else {
            return redirect()->route('frontend.social.home')->with('error', 'Not Verified.');
        }
    }

    public function removeTwitterAccount($id) {
        $socialMedia = Socialmedia::find($id);
        if($socialMedia) {
            $socialMedia->delete();
        }
        return redirect()->back();
    }

    public function accountWorth(Request $request){
      $account= null; $followers = 0;
      $found = false;
      if($request->type == 'instagram'){
        $socialMedia = Socialmedia::where([['account_handle', $request->handle],['account_type', 'Instagram']])->first();
        if($socialMedia) {
            $followers = $socialMedia->followers_count;

            $account['account_handle'] = $request->handle;
            $account['name'] = $socialMedia->account_name;
            $account['followers'] = SocialmediaObject::number_format_short($socialMedia->followers_count);
            $account['following'] = SocialMediaObject::number_format_short($socialMedia->following_count);
            $account['picture'] = $socialMedia->profile_picture;
            $found = true;
        } else {
            $socialMediaObject = new SocialmediaObject();
            $feed = $socialMediaObject->getInstagramFeeds($request->handle);
            if ($feed) {
                $followers = $feed->getFollowers();

                $account['account_handle'] = $request->handle;
                $account['name'] = $feed->getFullName();
                $account['followers'] = $socialMediaObject::number_format_short($feed->getFollowers());
                $account['following'] = $socialMediaObject::number_format_short($feed->getFollowing());
                $account['picture'] = $feed->getProfilePicture();
                $found = true;
            } else {
                return response()->json(['status' => 404]);
            }
        }
      }else if($request->type == 'tiktok'){
        $socialMedia = Socialmedia::where([['account_handle', $request->handle],['account_type', 'Tiktok']])->first();
        if($socialMedia) {
          $followers = $socialMedia->followers_count;

          $account['account_handle'] = $request->handle;
          $account['name'] = $socialMedia->account_name;
          $account['followers'] = SocialmediaObject::number_format_short($socialMedia->followers_count);
          $account['following'] = SocialMediaObject::number_format_short($socialMedia->following_count);
          $account['picture'] = $socialMedia->profile_picture;
          $found = true;
        } else {
            $socialMediaObject = new SocialmediaObject();
            $feed = $socialMediaObject->getTiktokFeeds($request->handle);
            if ($feed) {
                $followers = $feed->stats->followerCount;

                $account['account_handle'] = $request->handle;
                $account['name'] = $feed->user->avatarMedium;
                $account['followers'] = $socialMediaObject::number_format_short($feed->stats->followerCount);
                $account['following'] = $socialMediaObject::number_format_short($feed->stats->followingCount);
                $account['picture'] = $feed->user->avatarThumb;
                $found = true;
            } else {
                return response()->json(['status' => 404]);
            }
        }
      }
      if($found){
        $related_account = Socialmedia::where('socialmedias.status' , 'Verified')
            ->join('orders' , 'orders.influencer_id' , '=' , 'socialmedias.id')
            ->where('orders.status', 'completed')
            ->select('socialmedias.followers_count' , DB::raw('ABS(socialmedias.followers_count - '.$followers.' ) as difference'), DB::raw('SUM(orders.amount) as earning'))
            ->orderBy('difference')
            ->groupBy('socialmedias.followers_count')
            ->first();

        if($related_account){
          return response()->json(['account' => $account , 'related' => $related_account, 'status' => 200]);
        }else{
          return response()->json(['account' => $account , 'related' => null, 'status' => 100]);
        }

      }else{
        return response()->json(['status' => 404]);
      }

      }

      public function updateSocialAccountDetails() {
          $socialMediaObject = new SocialmediaObject();
          $socialMediaObject->updateSocialAccountDetails();
      }

      public function getTiktokFeeds($accountHandle) {
          $socialMediaObject = new SocialmediaObject();
          $feeds = $socialMediaObject->getTiktokFeeds($accountHandle);
      }

      public function testTiktok($accountHandle) {
        //return view('test_tiktok', ['accountHandle' => $accountHandle]);
          $socialMediaObject = new SocialmediaObject();
          $feeds = $socialMediaObject->scrape_tiktok_api($accountHandle);
      }

      public function getInstagramFeeds($accountHandle) {
          $socialMediaObject = new SocialmediaObject();
          $feeds = $socialMediaObject->getInstagramFeeds($accountHandle);
      }

}

