<?php


namespace App\Http\Controllers\Frontend;
use App\Campaign;
use App\Cart;
use App\CartItem;
use App\Http\Controllers\Controller;
use App\Post;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Traits\UploadTrait;
use Illuminate\Support\Facades\Storage;

class UserCartsController extends Controller
{
    use UploadTrait;
    public function addToCart($id) {
        if(!Auth::check()) {
            return 'auth_error';
        }
        $user = Auth::user();
        /*if($user->role->title != 'User') {
            return 'access_error';
        }*/
        $cart = Cart::where('user_id', $user->id)->where('status', 'new')->first();
        if(!$cart) {
            $cart = new Cart();
            $cart->user_id = $user->id;
            $cart->status = 'new';
            $cart->save();
        }

        $cartItem = $cart->cart_items()->where('campaign_id', $id)->first();
        if( $cartItem ) {
            $cartItem->no_of_items += 1;
            $cartItem->save();

        } else {
            $cartItem = new CartItem();
            $cartItem->campaign_id = $id;
            $cartItem->cart_id = $cart->id;
            $cartItem->save();
        }
        if($cartItem) {
            return 'success';
        }
        return 'query_error';
    }

    public function campaignsCart() {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        /*if($user->role->title != 'User') {
            return redirect('/')->with('error', 'You do not have permissions to this page.');
        }*/
        $cart = $user->cart;
        $cartItems = $cart ? $cart->cart_items()->paginate(3) : null;
        $data = [
            'cart' => $cart,
            'cartItems' => $cartItems
        ];
        return view('frontend.cart.campaign_cart', $data);
    }

    /*public function deleteCartItem($id) {
        if(!Auth::check()) {
            return 'You are not Logged in.';
        }
        $user = Auth::user();
        if($user->role->title != 'User') {
            return 'You do not have permissions to delete it.';
        }
        $cartItem = CartItem::find($id);
        $noOfItems = 0;
        if($cartItem && $cartItem->no_of_items > 1) {
            $cartItem->no_of_items -= 1;
            $cartItem->save();
            $noOfItems = $cartItem->no_of_items;

        } else if($cartItem) {
            $cartItem->delete();
        }
        if(sizeof($user->cart->cart_items) == 0) {
            if(sizeof($user->cart->posts) > 0) {
                foreach ($user->cart->posts as $post) {
                    $post->delete();
                }
            }
            $user->cart->delete();
        }
        return $noOfItems;
    }*/

    public function createCampaignPost(Request $request) {
        $camp_id = $request->input('campaign_id');
        if(is_null($camp_id)){
          return redirect('/')->with('error', 'Action not Allowed');
        }
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $campaign = Campaign::find($camp_id);
        /*if($user->role->title != 'User') {
            return redirect('/')->with('error', 'You do not have permissions to this page.');
        }*/
        /*$cart = $user->cart;
        $cartItems = $cart ? $cart->cart_items : null;
        $selectedCampaign = null;
        if($cartItems) {
            foreach ($cartItems as $cartItem) {
                $campaign = $cartItem->campaign;
                $post = Post::where('campaign_id', $campaign->id)->where('brand_id', $user->id)->where('cart_id', $cart->id)->where('influencer_id', $campaign->influencer_id)->where('status', 'new')->first();
                if (!$post) {
                    $selectedCampaign = $campaign;
                    break;
                } else if($campaign->post) {

                }
            }
        }
        if($selectedCampaign) {
            $data = [
                'campaign' => $selectedCampaign,
                'user' => $user
            ];
            return view('frontend.cart.add_post', $data);
        } else {
            return redirect()->route('frontend.user.campaign_cart_details');
        }*/

        $cart = Cart::where('user_id', $user->id)->first();
        if(!$cart) {
          $cart = new Cart();
          $cart->user_id = $user->id;
          $cart->status = 'new';
          $cart->save();
        }

      $data = [
          'campaign' => $campaign,
          'user' => $user,
          'cart' => $cart
      ];
      return view('frontend.cart.add_post', $data);



    }

    public function campaignCartDetails(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $cart = $user->cart;
        $paginate = isset($request->pages) ? $request->pages : 10;
        //$cartItems = $cart ? $cart->posts()->paginate($paginate) : null;

        $cartItems = Post::where('cart_id' , $cart->id)->where('posts.status' , 'new')
                          ->leftJoin('campaigns' , 'campaigns.id' , '=', 'posts.campaign_id')
                          ->leftJoin('socialmedias' , 'socialmedias.id' , '=', 'posts.influencer_id')
                          ->select('posts.*' , 'campaigns.title', 'campaigns.price' , 'socialmedias.account_handle')
                          ->orderBy('posts.created_at')
                          ->paginate($paginate);

        $data = [
            'user' => $user,
            'cart' => $cart,
            'cartItems' => $cartItems,
            /*'allCartItems' => $cart ? $cart->cart_items : null*/
        ];
        return view('frontend.cart.campaign_cart_details', $data);
    }

    public function storeCampaignPost(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $post = Post::create($request->all());
        $this->uploadPostImage($request, $post);
        return redirect()->route('frontend.user.campaign_cart_details');
    }

    public function buyCampaignPost(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $request->status = 'buy_now';
        $post = Post::create($request->all());
        $this->uploadPostImage($request, $post);
        return redirect()->route('frontend.user.checkout',['id' => $post->id]);
    }

    public function uploadPostImage(Request $request, Post $post){
        // Check if a profile image has been uploaded
        if ($request->has('image')) {
            // Get image file

            $image = $request->file('image');
            // Make a image name based on user name and current timestamp
            $name = $post->id .'_'.time();
            // Define folder path
            $folder = 'uploads/images/';

            $old_image = $post->image;
            $old_video = $post->video;

            if(!is_dir($folder.$old_image) && !empty($old_image) && Storage::disk('public')->exists($folder.$old_image)){
              unlink($folder.$old_image);
            }
            if(!is_dir($folder.$old_image) && !empty($old_video) && Storage::disk('public')->exists($folder.$old_video)){
              unlink($folder.$old_video);
            }
            // Make a file path where image will be stored [ folder path + file name + file extension]
            $extension = $image->getClientOriginalExtension();
            $filePath = $folder . $name. '.' . $extension;
            // Upload image
            $this->uploadOne($image, $folder, 'public', $name);
            // Set user profile image path in database to filePath
          if($extension == 'mp4'){
            $post->video = $name . '.' . $extension;
            $post->image = '';
          }else{
            $post->image = $name . '.' . $extension;
            $post->video = '';
          }

        }
        // Persist user record to database
        $post->save();
    }

    public function deleteCartItem($id){
      $post = Post::find($id);

      if(Auth::user()->id == $post->brand_id){
        $folder = 'uploads/images/';
        $old_image = $post->image;
        $old_video = $post->video;
        if(!is_dir($folder.$old_image) && !empty($old_image) && Storage::disk('public')->exists($folder.$old_image)){
          unlink($folder.$old_image);
        }
        if(!is_dir($folder.$old_video) && !empty($old_video) && Storage::disk('public')->exists($folder.$old_video)){
          unlink($folder.$old_video);
        }
        $post->delete();
      }

      return redirect()->route('frontend.user.campaign_cart_details');
    }

    public function editCartItem($id){
      $post = Post::find($id);

      if(Auth::user()->id == $post->brand_id){
        $campaign = Campaign::find($post->campaign_id);
        $data = [
            'post' => $post,
            'campaign' => $campaign
        ];
        return view('frontend.cart.add_post' , $data);
      }
      return redirect('/');
    }

    public function updateCartItem(Request $request , $id){
      $post = Post::find($id);

      if(Auth::user()->id == $post->brand_id){

        $post->description = isset($request->description) ? $request->description : $post->description;
        $post->start_date = isset($request->start_date) ? $request->start_date : $post->start_date;
        $post->link = isset($request->link) ? $request->link : $post->link;

        if($post->save()){
          $this->uploadPostImage($request, $post);
        }

        return redirect()->route('frontend.user.campaign_cart_details');
      }
      return redirect('/');
    }
}
