<?php


namespace App\Http\Controllers\Frontend;
use App\Campaign;
use App\Http\Controllers\Controller;
use App\Notification;
use App\Notifications\ChatInvitation;
use App\Order;
use App\Package;
use App\Post;
use App\Role;
use App\Service;
use App\Socialmedia;
use App\SocialmediaObject;
use App\Tag;
use App\User;
use Illuminate\Http\Request;
use App\Http\Requests;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;

class UsersController extends Controller
{
    public function editProfile() {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $timezonesList = \DateTimeZone::listIdentifiers(\DateTimeZone::ALL);
        return view('frontend.edit_profile', compact('user', 'timezonesList'));
    }

    public function validateRequest(Request $request) {

        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users,email,' . Auth::user()->id],
            'username' => ['string', 'max:255', 'unique:users,username,' . Auth::user()->id],
            'phone' => ['required', 'numeric', 'digits_between:10,11'],

            'country' => ['nullable', 'string'],
            'city' => ['nullable', 'string'],
            'zip_code' => ['nullable', 'string']
        ]);
        return $validatedData;
    }

    public function updateProfile(Request $request) {
        $this->validateRequest($request);
        $user = Auth::user();
        $user->update($request->all());
        return $user;
        //return redirect()->route('frontend.user.edit_profile')->with('success', 'Profile is updated Successfully.');
    }

    public function userCampaigns($status) {

        //$sortBy = isset($_REQUEST['sort_by']) ? $_REQUEST['sort_by'] : 'id';
        $sortBy = 'created_at';

        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        /*if($user->role->title != 'User') {
            return redirect('/')->with('error', 'You do not have permissions to this page.');
        }*/

       /* $social_media = $user->social_medias();
        dd($social_media);*/
        $campaigns = null;
        if ( $status == 'all' ) {
            //$campaigns = $user->campaigns()->orderBy($sortBy)->paginate(10);
          $campaigns = Campaign::leftJoin('socialmedias' , 'campaigns.social_media_id' , '=' , 'socialmedias.id')
                                ->where('socialmedias.user_id' , $user->id)
                                ->select('campaigns.*','socialmedias.account_handle', 'socialmedias.id as account_id')
                                ->orderBy($sortBy)->paginate(10);
            //dd($campaigns);
        } else if($status == 'in-progress' ){
            $campaigns = Order::whereRaw('orders.payment_status = "paid" AND orders.status != "rejected" AND orders.status != "new"')
                          /*->leftJoin('posts' , 'posts.id' , '=' , 'orders.post_id')*/
                          ->leftJoin('users' , 'orders.buyer_id' , '=' , 'users.id')
                          ->leftJoin('socialmedias' , 'socialmedias.id' , '=' , 'orders.influencer_id')
                          ->where('socialmedias.user_id' , Auth::user()->id)
                          ->select(
                              'orders.*',
                              'socialmedias.account_handle',
                              'users.name as buyer_name'
                          )->paginate(10);
                          //dd($campaigns);
        }

        if($campaigns) {

            $data = [
                'campaigns' => $campaigns
            ];

            if ( $status == 'in-progress' ) {
                return view('frontend.influencer_campaigns_in_progress', $data);
            } else if ($status == 'completed') {
                return view('frontend.influencer_campaigns_completed', $data);
            } if ( $status == 'all' ) {
                return view('frontend.influencer_campaigns_all', $data);
            }
        }
        return redirect('/')->with('error', 'Invalid Campaign Status');
    }

    public function userNotifications(Request $request) {
        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }
        $user = Auth::user();
        $notifications = Notification::where('to_user_id', $user->id)->orderBy('created_at' , 'desc')->paginate(10);
        //dd($notifications);
        $data = [
            'notifications' => $notifications
        ];
        $ajax = $request->input('flag');
        if(isset($ajax) && $request->input('flag') == true){
          return view('partials.ajax_notifications' , $data);
        }else{
          return view('frontend.user_notifications', $data);
        }

    }

    public function userMessages(Request $request) {

        if(!Auth::check()) {
            return redirect('/')->with('error', 'You are not Logged in.');
        }

        $user = User::where('id', $request->user_id)->first(['id', 'name']);

        if(!$user) {
            return redirect('/')->with('error', 'Invalid user id');
        }

        $data = [
            'user' => $user
        ];

        return view('frontend.user_messages', $data);

    }

    public function archivedChat(Request $request) {

        if(!Auth::check()) {
            return redirect('/')->with('error', 'You cannot access this page.');
        }

        $buyer = User::where('id', $request->buyer_id)->first(['id', 'name']);
        $seller = User::where('id', $request->seller_id)->first(['id', 'name']);

        if(!$buyer || !$seller) {
            return redirect('/')->with('error', 'Invalid user id');
        }

        $data = [
            'buyer' => $buyer,
            'seller' => $seller
        ];

        return view('frontend.archived_chat', $data);

    }

    public function readNotification($id){
      $notification = Notification::find($id);
      $notification->status = 'Read';
      $notification->save();

      return redirect($notification->url);
    }

    public function getNotificationDetails($id){
        $notification = Notification::find($id);
        $notification->status = 'Read';
        $notification->save();
        return [
            'message' => $notification->message,
            'sent_by' => $notification->sender->name,
            'status' => $notification->status
        ];
    }

    public function influencerDetails($id) {

        $influencer = Socialmedia::find($id);
        $user = User::find($influencer->user_id);
        if($influencer){
          $campaigns = Campaign::where('admin_status', 'approved')->where('social_media_id', $influencer->id);
          if(Auth::check()){
            if(Auth::user()->id !== $influencer->user_id){
              $campaigns = $campaigns->where('status' , 'enabled');
            }
          }else{
            $campaigns = $campaigns->where('status' , 'enabled');
          }
          $campaigns = $campaigns->get();

          /*if(!$socialMedia) {
              $socialMediaObject = new SocialmediaObject();
              $cloutsource_score = $socialMediaObject->getCloutSourceScore($influencer->id);

              $feedsDetails = [
                  'profile_picture' => asset('images/default.jpg'),
                  'account_handle' => $influencer->name,
                  'followers_count' => 0,
                  'avg_likes' => 0,
                  'avg_comments' => 0,
                  'total_posts' => 0,
                  'score' => $cloutsource_score
              ];
          } else if($socialMedia) {

              $socialMediaObject = new SocialmediaObject();
              $initialisedSocialMediaObject = $socialMediaObject->initializeSocialMediaObject($socialMedia->account_type, $socialMedia->account_handle);
              $feeds = $initialisedSocialMediaObject->getSocialAccountFeedsDetails();
              foreach($feeds as $key => $value){
                  $feedsDetails[$key] = $value;
              }
              $feedsDetails['score'] = $socialMediaObject->getScore();

          }*/

          $services = Service::all();
          $selectedServices = \DB::table('service_socialmedia')
                ->select('service_id')
                ->where('socialmedia_id', $influencer->id)
                ->pluck('service_id')->toArray();

          $tags = Tag::all();
          $selectedTags = \DB::table('socialmedia_tag')
                ->select('tag_id')
                ->where('socialmedia_id', $influencer->id)
                ->pluck('tag_id')->toArray();


          $data = [
              'campaigns' => $campaigns,
            /*'feedsDetails' => $feedsDetails,*/
              'influencer' => $influencer,
              'user' => $user,
              'services' => $services,
              'selectedServices' => $selectedServices,
              'tags' => $tags,
              'selectedTags' => $selectedTags
          ];
          // dd($data);
          return view('frontend.cart.influencer_details', $data);
        }
        else{
          return abort('404');
        }
    }

    public function updateTagsServices(Request $request) {
        \DB::table('socialmedia_tag')
            ->where('socialmedia_id', $request->influencer_id)
            ->delete();

        \DB::table('service_socialmedia')
            ->where('socialmedia_id', $request->influencer_id)
            ->delete();

        $tags = $request->tags;
        if($tags) {
            foreach ($tags as $tag) {
                \DB::table('socialmedia_tag')->insert(
                    ['socialmedia_id' => $request->influencer_id, 'tag_id' => $tag]
                );
            }
        }

        $services = $request->services;
        if($services) {
            foreach ($services as $service) {
                \DB::table('service_socialmedia')->insert(
                    ['socialmedia_id' => $request->influencer_id, 'service_id' => $service]
                );
            }
        }

        // address and extra notes
        $influencer = Socialmedia::find($request->influencer_id);
        $influencer->country = $request->country;
        $influencer->city = $request->city;
        $influencer->zip_code = $request->zip_code;
        $influencer->extra_note = $request->extra_note;
        $influencer->save();

        return back();
    }

  public function browseInfluencers(Request $request) {

    $tags = Tag::all();
    $services = Service::all();
    $paginate = isset($request->pages) ? $request->pages : 10;
    $searchText = isset($request->search_text) ? $request->search_text : null;
    $selectedTags = isset($request->selected_tags) ? $request->selected_tags : null;
    $selectedServices = isset($request->selected_services) ? $request->selected_services : null;

    $country = isset($request->country) ? $request->country : null;
    $city = isset($request->city) ? $request->city : null;
    $state = isset($request->state) ? $request->state : null;
    $zip_code = isset($request->zip_code) ? $request->zip_code : null;

    $no_of_followers = isset($request->no_of_followers) ? $request->no_of_followers : null;

    $selectedTagsArray = $selectedTags != '' ? explode(',', $selectedTags) : [];
    $selectedServicesArray = $selectedServices != '' ? explode(',', $selectedServices) : [];
    $influencers = Socialmedia::where('socialmedias.status' , 'Verified')
                    ->join('campaigns' , 'campaigns.social_media_id' , '=' , 'socialmedias.id')
                    ->where('campaigns.deleted_at' , null)
                    ->select(
                        'socialmedias.*'
                    );

    if(!is_null($searchText)){

        $influencers = $influencers->where(function($query) use ($searchText) {
            return $query->where('socialmedias.account_name' , 'like' , '%'.$searchText.'%')
                ->orWhere('socialmedias.account_handle' , 'like' , '%'.$searchText.'%');
        });
      //$influencers = $influencers->where('socialmedias.account_name' , 'like' , '%'.$searchText.'%')->orWhere('socialmedias.account_handle' , 'like' , '%'.$searchText.'%');
    }

    if(!is_null($country) || !is_null($city) || !is_null($zip_code)) {
        //$influencers = $influencers->join('users', 'socialmedias.user_id' , 'users.id');
        if(!is_null($country)) {
          $influencers = $influencers->where('socialmedias.country', 'like' , '%'.$country.'%');
        }
        if(!is_null($city)) {
            $influencers = $influencers->where('socialmedias.city', 'like' , '%'.$city.'%');
        }
        if(!is_null($zip_code)) {
            $influencers = $influencers->where('socialmedias.zip_code', 'like' , '%'.$zip_code.'%');
        }
    }

    if(!is_null($no_of_followers)) {
        if($no_of_followers == '0-1k') {
            $influencers = $influencers->whereBetween('socialmedias.followers_count', [0, 1000]);
        }
        if($no_of_followers == '1k-7k') {
            $influencers = $influencers->whereBetween('socialmedias.followers_count', [1000, 7000]);
        }
        if($no_of_followers == 'more-than-7k') {
            $influencers = $influencers->where('socialmedias.followers_count', '>', 7000);
        }
    }

    if(!is_null($selectedTags)){
      //$influencers = $influencers->join('taggables' , 'taggables.influencer_id' , 'socialmedias.id')->whereIn('taggables.tag_id' , $selectedTagsArray);
        $influencers = $influencers->join('socialmedia_tag' , 'socialmedia_tag.socialmedia_id' , 'socialmedias.id')->whereIn('socialmedia_tag.tag_id' , $selectedTagsArray);
    }

      if(!is_null($selectedServices)){
          $influencers = $influencers->join('service_socialmedia' , 'service_socialmedia.socialmedia_id' , 'socialmedias.id')->whereIn('service_socialmedia.service_id' , $selectedServicesArray);
      }


    $influencers = $influencers->distinct()->orderBy('socialmedias.followers_count', 'desc')->simplePaginate($paginate , 'socialmedias');

    //dd($influencers);

    foreach ($influencers as $key => $influencer){
      $campaign = Campaign::where('social_media_id' , $influencer->id)->select(
          DB::raw("MAX(price) AS max_price"),
          DB::raw("MIN(price) AS min_price")
      )->groupBy('social_media_id')->first();

      $influencers[$key]->price_range = $campaign ? '$'.$campaign->min_price.'-'.'$'.$campaign->max_price : '$0-$0';
    }

    $inputs = [
        'searchText', $searchText,
        'paginate' => $paginate
    ];

    $data = [
        'influencers'  => $influencers,
        'tags' => $tags,
        'services' => $services,
        'inputs', $inputs
    ];

    if(isset($request->ajax)) {
        return view('partials.ajax_influencers_section', $data);
    } else {
        return view('frontend.cart.browse_influencer', $data);
    }

  }

  public function userDashboard(){
      return view('frontend.user.user_dashboard');
  }
  public function adminDashboard(){

      if(!Auth::check()) {
          return redirect('/')->with('error', 'You are not Logged in.');
      }

      $user = Auth::user();
      $currentYear = date('Y');

      // all months earnings
      $allMonthsEarnings = [];
      $thisYearEarning = 0;
      $thisMonthEarning = 0;
      for ($i = 1; $i <= 12; $i++) {
          $eachMonthEarningQuery = 'select sum(transaction_amount) as total from transactions where user_id=' . $user->id . ' and type="deposit" and month(created_at) = ' . sprintf("%02d", $i) . ' and year(created_at) = ' . $currentYear;
          $eachMonthEarningResult = DB::select($eachMonthEarningQuery);
          $eachMonthEarning = $eachMonthEarningResult && isset($eachMonthEarningResult[0]->total) ? $eachMonthEarningResult[0]->total : 0;
          $allMonthsEarnings[$i] = $eachMonthEarning;
          $thisYearEarning += $allMonthsEarnings[$i];
          if(date('m') == sprintf("%02d", $i)) {
              $thisMonthEarning = $allMonthsEarnings[$i];
          }
      }

      // total earning
      $totalEarningQuery = 'select sum(transaction_amount) as total from transactions where user_id=' . $user->id . ' and type="deposit"';
      $totalEarningResult = DB::select($totalEarningQuery);
      $totalEarning = $totalEarningResult && isset($totalEarningResult[0]->total) ? $totalEarningResult[0]->total : 0;

      $tiktokAccountsCount = Socialmedia::where([['user_id', $user->id],['account_type', 'Tiktok']])->count();
      $instagramAccountsCount = Socialmedia::where([['user_id', $user->id],['account_type', 'Instagram']])->count();
      $featuredCount = Socialmedia::where([['user_id', $user->id],['is_featured', 1]])->count();

      $earningDetails = [
          'allMonthsEarnings' => $allMonthsEarnings,
          'totalEarning' => $totalEarning,
          'thisYearEarning' => $thisYearEarning,
          'thisMonthEarning' => $thisMonthEarning,

          'janEarning' => $allMonthsEarnings[1],
          'febEarning' => $allMonthsEarnings[2],
          'marEarning' => $allMonthsEarnings[3],
          'aprEarning' => $allMonthsEarnings[4],
          'mayEarning' => $allMonthsEarnings[5],

          'tiktokAccountsCount' => $tiktokAccountsCount,
          'instagramAccountsCount' => $instagramAccountsCount,
          'featuredCount' => $featuredCount

      ];

      //echo "<pre>"; print_r($earningDetails); exit;

      $data = [
          'earningDetails' => $earningDetails,
      ];

      return view('frontend.user.admin_dashboard', $data);
      
  }

  public function uploadChatAttachments(Request $request) {

      $response = [];
      foreach($request->file('files') as $file) {
          $originalName = $file->getClientOriginalName();
          $extension = $file->getClientOriginalExtension();
          $nameWithoutExtension = $request->my_id .'-' . $request->user_id . '-'  . uniqid();
          $name = $nameWithoutExtension . '.' . $extension;
          $file->move(public_path() . '/uploads/images', $name);
          $response[] = url('uploads/images/' . $name) . ', ' . $originalName;
      }
      return $response;
  }

  public function sendChatInviteEmailAndNotification(Request $request) {
    //$sender = Socialmedia::where('id', $request->sender_id)->first(['id', 'user_id']);
    //$receiver = Socialmedia::where('id', $request->receiver_id)->first(['id', 'user_id']);
    $receiver = User::find($request->receiver_id);
    $sender = User::find($request->sender_id);
    $receiver->notify(new ChatInvitation($sender));

    // create notification
    $notification = new Notification();
    $notification->from_user_id = $sender->id;
    $notification->to_user_id = $receiver->id;
    $message = 'There is a chat Invitation, Please click the link to accept/reject it. <a href="' . url('frontend/user_messages?user_id=' . $sender->id) . '">Accept/Reject Invitation</a>';
    $notification->message = $message;
    $notification->save();
    // create notification ends
  }

}
