<?php

namespace App;

use Carbon\Carbon;
use Hash;
use Illuminate\Auth\Notifications\ResetPassword;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use App\Notifications\ResetPasswordNotification;

class User extends Authenticatable
{
    //use SoftDeletes;
    use Notifiable;

    protected $hidden = [
        'password',
        'remember_token',
    ];

    protected $dates = [
        'updated_at',
        'created_at',
        'deleted_at',
        'email_verified_at',
    ];

    protected $fillable = [
        'name',
        'role_id',
        'email',
        'username',
        'timezone',
        'skype',
        'website',
        'phone',
        'referral_code',
        'password',
        'country',
        'city',
        'zip_code',
        'created_at',
        'updated_at',
        'deleted_at',
        'remember_token',
        'email_verified_at',
    ];

    public function getEmailVerifiedAtAttribute($value)
    {
        return $value ? Carbon::createFromFormat('Y-m-d H:i:s', $value)->format(config('panel.date_format') . ' ' . config('panel.time_format')) : null;
    }

    public function setEmailVerifiedAtAttribute($value)
    {
        $this->attributes['email_verified_at'] = $value ? Carbon::createFromFormat(config('panel.date_format') . ' ' . config('panel.time_format'), $value)->format('Y-m-d H:i:s') : null;
    }

    public function setPasswordAttribute($input)
    {
        if ($input) {
            $this->attributes['password'] = app('hash')->needsRehash($input) ? Hash::make($input) : $input;
        }
    }

    public function sendPasswordResetNotification($token)
    {
        //$this->notify(new ResetPassword($token));
        $this->notify(new ResetPasswordNotification($token));
    }

    public function roles()
    {
        return $this->belongsToMany(Role::class);
    }

    public function role()
    {
        return $this->belongsTo(Role::class);
    }

    public function campaigns() {
        return $this->hasMany('App\Campaign', 'influencer_id');
    }

    public function cart()
    {
        return $this->hasOne('App\Cart', 'user_id')->where('status', 'new');
    }

    public function social_medias() {
        return $this->hasMany('App\Socialmedia', 'user_id');
    }

    public function demography() {
        return $this->hasOne('App\Demography', 'influencer_id');
    }

    public function tags()
    {
        return $this->belongsToMany(Tag::class);
    }

    public function featured_influencer() {
        return $this->hasOne('App\FeaturedInfluencer', 'influencer_id');
    }

    public function posts() {
        return $this->hasOne('App\Post', 'influencer_id');
    }

    public function referral_user( $code ) {
        return User::where('referral_code', $code)->first();
    }
}
