@extends('layouts.admin')
@section('content')

    <div class="card">
        <div class="card-header">
            {{ trans('global.edit') }} {{ trans('global.ticket.title_singular') }}
        </div>

        <div class="card-body">
            <form action="{{ route("admin.tickets.update", [$ticket->id]) }}" method="POST" enctype="multipart/form-data">
                @csrf
                @method('PUT')
                <div class="form-group {{ $errors->has('name') ? 'has-error' : '' }}">
                    <label for="start_date">{{ trans('global.ticket.fields.subject') }}</label>
                    <input type="text" name="subject" class="form-control" value="{{ $ticket->subject }}">
                    @if($errors->has('subject'))
                        <em class="invalid-feedback">
                            {{ $errors->first('subject') }}
                        </em>
                    @endif
                    <p class="helper-block">
                        {{ trans('global.ticket.fields.subject_helper') }}
                    </p>
                </div>

                <div class="form-group {{ $errors->has('user_id') ? 'has-error' : '' }}">
                    <label for="against_user_id">{{ trans('global.ticket.fields.against_user_name') }}*</label>
                    <select  class="form-control" name="against_user_id">
                        <option value="0">Not Against any User</option>
                        @foreach($users as $user)
                            <option {{ $user->id == $ticket->against_user_id ? 'selected' : '' }} value="{{ $user->id }}">{{ $user->name }}</option>
                        @endforeach
                    </select>

                    @if($errors->has('against_user_id'))
                        <em class="invalid-feedback">
                            {{ $errors->first('against_user_id') }}
                        </em>
                    @endif
                    <p class="helper-block">
                        {{ trans('global.ticket.fields.against_user_name_helper') }}
                    </p>
                </div>
                <div class="form-group {{ $errors->has('description') ? 'has-error' : '' }}">
                    <label for="post_id">{{ trans('global.ticket.fields.description') }}*</label>
                    <textarea name="description" class="form-control"> {{ $ticket->description }} </textarea>

                    @if($errors->has('description'))
                        <em class="invalid-feedback">
                            {{ $errors->first('description') }}
                        </em>
                    @endif
                    <p class="helper-block">
                        {{ trans('global.ticket.fields.description_helper') }}
                    </p>
                </div>

                <div class="form-group {{ $errors->has('status') ? 'has-error' : '' }}">
                    <label for="status">{{ trans('global.ticket.fields.status') }}*</label>
                    <select  class="form-control" name="status">
                        <option value="initiated">Initiated</option>
                        <option value="processed">Processed</option>
                    </select>

                    @if($errors->has('status'))
                        <em class="invalid-feedback">
                            {{ $errors->first('status') }}
                        </em>
                    @endif
                    <p class="helper-block">
                        {{ trans('global.ticket.fields.status_helper') }}
                    </p>
                </div>

                <div>
                    <input class="btn btn-danger" type="submit" value="{{ trans('global.save') }}">
                </div>
            </form>
        </div>
    </div>
@endsection

