@extends('layouts.admin')
@section('content')
    <div class="card">
        <div class="card-header">
            {{ trans('global.ticket.title_singular') }} {{ trans('global.list') }}
            @can('ticket_create')
                <a class="btn btn-success" href="{{ route("admin.tickets.create") }}" style="float: right;">
                    {{ trans('global.add') }} {{ trans('global.ticket.title_singular') }}
                </a>
            @endcan
        </div>

        <div class="card-body">
          
                <table class=" table table-bordered table-striped table-hover datatable table-responsive">
                    <thead>
                    <tr>
                        <th width="10">

                        </th>
                        <th>
                            {{ trans('global.ticket.fields.subject') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.user_name') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.against_user_name') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.type') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.status') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.description') }}
                        </th>
                        <th>
                            {{ trans('global.ticket.fields.created_at') }}
                        </th>
                        <th>
                            &nbsp;
                        </th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($tickets as $key => $ticket)
                        <tr data-entry-id="{{ $ticket->id }}">
                            <td>

                            </td>
                            <td>
                                {{ $ticket->subject ?? '' }}
                            </td>

                            <td>
                                {{ $ticket->user->name ?? '' }}
                            </td>
                            <td>
                                {{ $ticket->against_user_id != 0 ? ($ticket->against_user->name ?? '') : 'None' }}
                            </td>
                            <td>
                                {{ $ticket->type ?? '' }}
                            </td>
                            <td>
                                {{ $ticket->status ?? '' }}
                            </td>
                            <td>
                                {{ $ticket->description ?? '' }}
                            </td>
                            <td>
                                {{ $ticket->created_at ?? '' }}
                            </td>
                            <td>
                                @can('ticket_show')
                                    @if(!empty($ticket->order_id))
                                        <a class="btn btn-xs btn-success" href="{{route('frontend.user.order_details' , ['id' => $ticket->order_id])}}">
                                            View Order
                                        </a>
                                    @else
                                        <a class="btn btn-xs btn-primary" href="{{ route('admin.tickets.show', $ticket->id) }}">
                                            {{ trans('global.view') }}
                                        </a>
                                    @endif

                                @endcan

                                @if(Auth::user()->id == $ticket->user_id)
                                @can('ticket_edit')
                                    <a class="btn btn-xs btn-info" href="{{ route('admin.tickets.edit', $ticket->id) }}">
                                        {{ trans('global.edit') }}
                                    </a>
                                @endcan
                                @endif

                                @can('ticket_action')
                                    @if($ticket->status == 'Initiated')
                                        <a class="btn btn-xs btn-info" href="{{ route('admin.tickets.action', $ticket->id) }}">
                                                {{ trans('global.take_action') }}
                                        </a>
                                    @endif
                                @endcan

                                @can('ticket_delete')
                                    <form action="{{ route('admin.tickets.destroy', $ticket->id) }}" method="POST" onsubmit="return confirm('{{ trans('global.areYouSure') }}');" style="display: inline-block;">
                                        <input type="hidden" name="_method" value="DELETE">
                                        <input type="hidden" name="_token" value="{{ csrf_token() }}">
                                        <input type="submit" class="btn btn-xs btn-danger" value="{{ trans('global.delete') }}">
                                    </form>
                                @endcan

                                @if($ticket->order)
                                    <a class="btn btn-xs btn-info" href="{{ url('frontend/archived_chat?buyer_id=' . $ticket->order->buyer_id . '&seller_id=' . $ticket->order->seller_id) }}">
                                        Archived Chat
                                    </a>
                                @endif
                            </td>

                        </tr>
                    @endforeach
                    </tbody>
                </table>
            </div>
    </div>
@section('scripts')
    @parent
    <script>
        $(function () {
            let deleteButtonTrans = '{{ trans('global.datatables.delete') }}'
            let deleteButton = {
                text: deleteButtonTrans,
                url: "{{ route('admin.tickets.massDestroy') }}",
                className: 'btn-danger',
                action: function (e, dt, node, config) {
                    var ids = $.map(dt.rows({ selected: true }).nodes(), function (entry) {
                        return $(entry).data('entry-id')
                    });

                    if (ids.length === 0) {
                        alert('{{ trans('global.datatables.zero_selected') }}')

                        return
                    }

                    if (confirm('{{ trans('global.areYouSure') }}')) {
                        $.ajax({
                            headers: {'x-csrf-token': _token},
                            method: 'POST',
                            url: config.url,
                            data: { ids: ids, _method: 'DELETE' }})
                            .done(function () { location.reload() })
                    }
                }
            }
            let dtButtons = $.extend(true, [], $.fn.dataTable.defaults.buttons)
            @can('ticket_delete')
            dtButtons.push(deleteButton)
            @endcan

            $('.datatable:not(.ajaxTable)').DataTable({ buttons: dtButtons })
        })

    </script>
@endsection
@endsection

