@extends('layouts.admin')
@section('content')

<div class="card">
    <div class="card-header">
        {{ trans('global.create') }} {{ trans('global.user.title_singular') }}
    </div>

    <div class="card-body">
        <form method="POST" enctype="multipart/form-data" id="create_form">
            @csrf
            <input type="hidden" id="_token" name="_token" value="{{ csrf_token() }}">
            <div class="form-group {{ $errors->has('name') ? 'has-error' : '' }}">
                <label for="name">{{ trans('global.user.fields.name') }}*</label>
                <input type="text" id="name" name="name" class="form-control" value="{{ old('name', isset($user) ? $user->name : '') }}">

                    <em class="invalid-feedback" id="name_error" style="display: block">

                    </em>
                <p class="helper-block">
                    {{ trans('global.user.fields.name_helper') }}
                </p>
            </div>
            <div class="form-group {{ $errors->has('email') ? 'has-error' : '' }}">
                <label for="email">{{ trans('global.user.fields.email') }}*</label>
                <input type="email" id="email" name="email" class="form-control" value="{{ old('email', isset($user) ? $user->email : '') }}">

                    <em class="invalid-feedback" id="email_error" style="display: block">

                    </em>

                <p class="helper-block">
                    {{ trans('global.user.fields.email_helper') }}
                </p>
            </div>

            <div class="form-group {{ $errors->has('phone') ? 'has-error' : '' }}">
                <label for="name">{{ trans('global.user.fields.phone') }}*</label>
                <input type="text" id="phone" name="phone" class="form-control" value="{{ old('phone', isset($user) ? $user->phone : '') }}">

                    <em class="invalid-feedback" id="phone_error" style="display: block">

                    </em>

                <p class="helper-block">
                    {{ trans('global.user.fields.phone_helper') }}
                </p>
            </div>

            <div class="form-group {{ $errors->has('password') ? 'has-error' : '' }}">
                <label for="password">{{ trans('global.user.fields.password') }}</label>
                <input type="password" id="password" name="password" class="form-control">

                    <em class="invalid-feedback" id="password_error" style="display: block">

                    </em>

                <p class="helper-block">
                    {{ trans('global.user.fields.password_helper') }}
                </p>
            </div>

            <div class="form-group {{ $errors->has('country') ? 'has-error' : '' }}">
                <label for="address">Country</label>
                <input type="text" id="country" name="country" class="form-control" value="{{ old('country', isset($user) ? $user->country : '') }}">

                <em class="invalid-feedback" id="country_error" style="display: block">

                </em>

                <p class="helper-block">

                </p>
            </div>

            <div class="form-group {{ $errors->has('city') ? 'has-error' : '' }}">
                <label for="city">City</label>
                <input type="text" id="city" name="city" class="form-control" value="{{ old('city', isset($user) ? $user->city : '') }}">

                <em class="invalid-feedback" id="city_error" style="display: block">

                </em>

                <p class="helper-block">

                </p>
            </div>

            <div class="form-group {{ $errors->has('zip_code') ? 'has-error' : '' }}">
                <label for="name">Zip Code</label>
                <input type="text" id="zip_code" name="zip_code" class="form-control" value="{{ old('zip_code', isset($user) ? $user->zip_code : '') }}">

                <em class="invalid-feedback" id="zip_code_error" style="display: block">

                </em>

                <p class="helper-block">

                </p>
            </div>

            <input type="hidden" name="role_id" value="2">
            <div>
                <input id="submit_button" class="btn btn-danger" type="button" value="{{ trans('global.save') }}">
            </div>
        </form>
    </div>
</div>

@endsection

@section('scripts')
    <script src="{!! asset('js/firebase/firebase-app.js') !!}"></script>
    <script src="{!! asset('js/firebase/firebase-firestore.js') !!}"></script>
    <script src="{!! asset('js/firebase/firebase-messaging.js') !!}"></script>
    <script src="{!! asset('js/firebase/firebase-chat-config.js') !!}"></script>
    <script src="{!! asset('js/helper.js') !!}"></script>

    <script>
        $(document).ready(function() {

            var frm = document.getElementById('create_form');

            $('#submit_button').on('click', function (event) {
                $('.invalid-feedback').hide();
                $.ajax({
                    url: "{{ route("admin.users.store") }}",
                    method: "POST",
                    data: new FormData(frm),
                    dataType: 'JSON',
                    contentType: false,
                    cache: false,
                    processData: false,
                    success: function (data) {
                        $('.invalid-feedback').hide();
                        db.collection(usersCollection).add({
                            id: data.id,
                            name: data.name,
                            avatar: "{{ url('images/default.jpg') }}",
                            blocked_users: [],
                            conversation_stopped_users: []
                        })
                            .then(function(docRef) {
                                console.log("Document written with ID: ", docRef.id);
                                window.location.href = "{{ url('admin/users') }}";
                            })
                            .catch(function(error) {
                                console.error("Error adding document: ", error);
                            });
                        //$('#myModal').modal('show');
                    },
                    error: function (data) {

                        var errors = data.responseJSON.errors;
                        $('.invalid-feedback').hide();
                        $.each(errors, function(key,val){
                            $('#' + key + '_error').show();
                            $('#' + key + '_error').html(errors[key]);
                        });
                        return false;
                    }

                });
                return false;
            });

        });
    </script>
@endsection
